@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco++/ncap2.cc,v 1.100 2009/06/26 16:25:55 hmb Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco++/ncap2.cc,v 1.106 2010/01/27 09:36:31 zender Exp $ */
 
 /* ncap2 -- netCDF arithmetic processor */
 
 /* Purpose: Compute user-defined derived fields using forward algebraic notation applied to netCDF files */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
    
    License: GNU General Public License (GPL) Version 3
    The full license text is at http://www.gnu.org/copyleft/gpl.html 
@@ -136,9 +136,9 @@ main(int argc,char **argv)
   char *spt_arg_cat=NULL_CEWI; /* [sng] User-specified script */
   
   const char * const att_nm_tmp="eulaVlliF_"; /* name used for netCDF4 name hack */
-  const char * const CVS_Id="$Id: ncap2.cc,v 1.100 2009/06/26 16:25:55 hmb Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.100 $";
-  const char * const opt_sht_lst="34ACcD:FfhL:l:n:Oo:p:Rrs:S:t:vx-:"; /* [sng] Single letter command line options */
+  const char * const CVS_Id="$Id: ncap2.cc,v 1.106 2010/01/27 09:36:31 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.106 $";
+  const char * const opt_sht_lst="346ACcD:FfhL:l:n:Oo:p:Rrs:S:t:vx-:"; /* [sng] Single letter command line options */
   
   dmn_sct **dmn_in=NULL_CEWI;  /* [lst] Dimensions in input file */
   dmn_sct *dmn_new;
@@ -301,6 +301,9 @@ main(int argc,char **argv)
     case '4': /* Catch-all to prescribe output storage format */
       if(!strcmp(opt_crr,"64bit")) fl_out_fmt=NC_FORMAT_64BIT; else fl_out_fmt=NC_FORMAT_NETCDF4; 
       break;
+    case '6': /* Request netCDF3 64-bit offset output storage format */
+      fl_out_fmt=NC_FORMAT_64BIT;
+      break;
     case 'A': /* Toggle FORCE_APPEND */
       FORCE_APPEND=!FORCE_APPEND;
       break;
@@ -391,7 +394,7 @@ main(int argc,char **argv)
       nco_exit(EXIT_FAILURE);
       break;
     } /* end switch */
-    if(opt_crr != NULL) opt_crr=(char *)nco_free(opt_crr);
+    if(opt_crr) opt_crr=(char *)nco_free(opt_crr);
   } /* end while loop */
   
   /* Append ";\n" to command-script arguments, then concatenate them */
@@ -411,7 +414,7 @@ main(int argc,char **argv)
   } /* end if */    
   
   /* create function/method vector */
-
+ 
   // Conversion functions
   cnv_cls cnv_obj(true);
   // Aggregate functions
@@ -436,6 +439,8 @@ main(int argc,char **argv)
   unr_cls unr_obj(true); 
   //array functions
   arr_cls arr_obj(true); 
+  //biliner interpolation functions
+  bil_cls bil_obj(true); 
 
   
   //populate vector
@@ -451,8 +456,9 @@ main(int argc,char **argv)
   (void)pop_fmc_vtr(fmc_vtr,&srt_obj);
   (void)pop_fmc_vtr(fmc_vtr,&unr_obj);
   (void)pop_fmc_vtr(fmc_vtr,&arr_obj);
-  
-
+  (void)pop_fmc_vtr(fmc_vtr,&bil_obj);
+   
+ 
   // GSL functions
 #ifdef ENABLE_GSL
   char *str_ptr;
@@ -461,18 +467,21 @@ main(int argc,char **argv)
   gsl2_cls gsl2_obj(true); 
   gsl_stt2_cls gsl_stt2_obj(true);
   gsl_spl_cls gsl_spl_obj(true);
+  gsl_fit_cls gsl_fit_obj(true);
+
  
   (void)pop_fmc_vtr(fmc_vtr,&gsl_obj);
   (void)pop_fmc_vtr(fmc_vtr,&gsl2_obj);
   (void)pop_fmc_vtr(fmc_vtr,&gsl_stt2_obj);
   (void)pop_fmc_vtr(fmc_vtr,&gsl_spl_obj);
+  (void)pop_fmc_vtr(fmc_vtr,&gsl_fit_obj);
 
   
   /* Set GSL error handler */
   gsl_set_error_handler_off(); 
   
   /* initialize global from environment variable */  
-  if((str_ptr=getenv("GSL_PREC_MODE")) != NULL) ncap_gsl_mode_prec=(int)strtol(str_ptr,(char **)NULL,10);
+  if((str_ptr=getenv("GSL_PREC_MODE"))) ncap_gsl_mode_prec=(int)strtol(str_ptr,(char **)NULL,10);
   
   if(ncap_gsl_mode_prec<0 || ncap_gsl_mode_prec>2) ncap_gsl_mode_prec=0;
 
@@ -555,7 +564,8 @@ main(int argc,char **argv)
   prs_arg.ATT_INHERIT=ATT_INHERIT;
   prs_arg.NCAP_MPI_SORT=(thr_nbr>1 ? true:false);
   
-  prs_arg.dfl_lvl=dfl_lvl; /* [enm] Deflate level */
+  prs_arg.dfl_lvl=dfl_lvl;  /* [enm] Deflate level */
+  prs_arg.cnk_sz=(size_t*)NULL; /* chunks sizes for now set to null */ 
   
 #ifdef NCO_NETCDF4_AND_FILLVALUE
   prs_arg.NCAP4_FILL = (fl_out_fmt==NC_FORMAT_NETCDF4 || fl_out_fmt==NC_FORMAT_NETCDF4_CLASSIC);
@@ -653,7 +663,7 @@ main(int argc,char **argv)
   /* Find and add any new dimensions to output */
   for(idx=0;idx<nbr_dmn_ass;idx++){
     dmn_item=dmn_out_vtr.find(dmn_lst[idx].nm);
-    if(dmn_item != NULL) continue;    
+    if(dmn_item) continue;    
     dmn_item=dmn_in_vtr.find(dmn_lst[idx].nm);
     if(dmn_item == NULL) continue;
     dmn_new=nco_dmn_dpl(dmn_item);
@@ -808,7 +818,7 @@ main(int argc,char **argv)
   /* Clean memory unless dirty memory allowed */
   if(flg_cln){
     /* ncap-specific memory */
-    if(fl_spt_usr != NULL_CEWI) fl_spt_usr=(char *)nco_free(fl_spt_usr);
+    if(fl_spt_usr) fl_spt_usr=(char *)nco_free(fl_spt_usr);
     
     /* Free extraction lists */ 
     xtr_lst=nco_nm_id_lst_free(xtr_lst,nbr_xtr);
@@ -816,20 +826,20 @@ main(int argc,char **argv)
     
     /* Free command line algebraic arguments, if any */
     for(idx=0;idx<nbr_spt;idx++) spt_arg[idx]=(char *)nco_free(spt_arg[idx]);
-    if(spt_arg_cat != NULL_CEWI) spt_arg_cat=(char *)nco_free(spt_arg_cat);
+    if(spt_arg_cat) spt_arg_cat=(char *)nco_free(spt_arg_cat);
     
     /* NCO-generic clean-up */
     /* Free individual strings/arrays */
-    if(cmd_ln != NULL_CEWI) cmd_ln=(char *)nco_free(cmd_ln);
-    if(fl_in != NULL_CEWI) fl_in=(char*)nco_free(fl_in);
-    if(fl_out != NULL_CEWI) fl_out=(char *)nco_free(fl_out);
-    if(fl_out_tmp != NULL_CEWI) fl_out_tmp=(char *)nco_free(fl_out_tmp);
-    if(fl_pth != NULL_CEWI) fl_pth=(char *)nco_free(fl_pth);
-    if(fl_pth_lcl != NULL_CEWI) fl_pth_lcl=(char *)nco_free(fl_pth_lcl);
+    if(cmd_ln) cmd_ln=(char *)nco_free(cmd_ln);
+    if(fl_in) fl_in=(char*)nco_free(fl_in);
+    if(fl_out) fl_out=(char *)nco_free(fl_out);
+    if(fl_out_tmp) fl_out_tmp=(char *)nco_free(fl_out_tmp);
+    if(fl_pth) fl_pth=(char *)nco_free(fl_pth);
+    if(fl_pth_lcl) fl_pth_lcl=(char *)nco_free(fl_pth_lcl);
     /* Free lists of strings */
-    if(fl_lst_in != NULL_CEWI && fl_lst_abb == NULL_CEWI) fl_lst_in=nco_sng_lst_free(fl_lst_in,fl_nbr); 
-    if(fl_lst_in != NULL_CEWI && fl_lst_abb != NULL_CEWI) fl_lst_in=nco_sng_lst_free(fl_lst_in,1);
-    if(fl_lst_abb != NULL_CEWI) fl_lst_abb=nco_sng_lst_free(fl_lst_abb,abb_arg_nbr);
+    if(fl_lst_in && fl_lst_abb == NULL_CEWI) fl_lst_in=nco_sng_lst_free(fl_lst_in,fl_nbr); 
+    if(fl_lst_in && fl_lst_abb) fl_lst_in=nco_sng_lst_free(fl_lst_in,1);
+    if(fl_lst_abb) fl_lst_abb=nco_sng_lst_free(fl_lst_abb,abb_arg_nbr);
     /* Free limits */
     for(idx=0;idx<lmt_nbr;idx++) lmt_arg[idx]=(char *)nco_free(lmt_arg[idx]);
     if(lmt_nbr > 0) lmt=nco_lmt_lst_free(lmt,lmt_nbr);
@@ -850,7 +860,7 @@ main(int argc,char **argv)
     }  
     
     /* Clear vectors */
-    
+    /*
     fmc_vtr.clear();
     cnv_obj.fmc_vtr.clear();
     agg_obj.fmc_vtr.clear();
@@ -862,7 +872,7 @@ main(int argc,char **argv)
     msk_obj.fmc_vtr.clear();
     pck_obj.fmc_vtr.clear();     
 
-
+    */
     /* Free variable lists */
     if(nbr_xtr > 0) var=nco_var_lst_free(var,nbr_xtr);
     if(nbr_xtr > 0) var_out=nco_var_lst_free(var_out,nbr_xtr);
