@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco++/ncap2_utl.cc,v 1.129 2009/05/07 13:36:51 hmb Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco++/ncap2_utl.cc,v 1.132 2010/01/27 16:04:50 hmb Exp $ */
 
 /* Purpose: netCDF arithmetic processor */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -317,7 +317,7 @@ prs_cls *prs_arg) /*Maybe used at some point */
       for(att_lmn=0;att_lmn<att_sz;att_lmn++) (void)fprintf(stdout,att_sng,var->val.sp[att_lmn],(att_lmn != att_sz-1) ? dlm_sng : "");
       break;
     case NC_INT:
-      for(att_lmn=0;att_lmn<att_sz;att_lmn++) (void)fprintf(stdout,att_sng,(long)var->val.lp[att_lmn],(att_lmn != att_sz-1) ? dlm_sng : "");
+      for(att_lmn=0;att_lmn<att_sz;att_lmn++) (void)fprintf(stdout,att_sng,(long)var->val.ip[att_lmn],(att_lmn != att_sz-1) ? dlm_sng : "");
       break;
     case NC_CHAR:
       for(att_lmn=0;att_lmn<att_sz;att_lmn++){
@@ -1310,7 +1310,7 @@ ncap_var_var_stc
 {
   static VarOp<double> Vd;
   static VarOp<float> Vf;
-  static VarOp<nco_int> Vl;
+  static VarOp<nco_int> Vi;
   static VarOp<nco_short> Vs;
   static VarOp<nco_ushort> Vus;
   static VarOp<nco_uint> Vui;
@@ -1318,6 +1318,7 @@ ncap_var_var_stc
   static VarOp<nco_uint64> Vui64;
   static VarOp<nco_byte> Vb;
   static VarOp<nco_ubyte> Vub;
+  static VarOp<nco_char> Vc;
   var_sct *var_ret=NULL_CEWI;
   
   //If var2 is null then we are dealing with a unary function
@@ -1326,7 +1327,7 @@ ncap_var_var_stc
     switch (var1->type) {
     case NC_DOUBLE: var_ret=Vd.var_op(var1,op); break;
     case NC_FLOAT: var_ret=Vf.var_op(var1,op); break;
-    case NC_INT: var_ret=Vl.var_op(var1,op); break;            
+    case NC_INT: var_ret=Vi.var_op(var1,op); break;            
     case NC_SHORT: var_ret=Vs.var_op(var1,op); break;
     case NC_USHORT: var_ret=Vus.var_op(var1,op); break;
     case NC_UINT: var_ret=Vui.var_op(var1,op); break;
@@ -1334,8 +1335,8 @@ ncap_var_var_stc
     case NC_UINT64: var_ret=Vui64.var_op(var1,op); break;
     case NC_BYTE: var_ret=Vb.var_op(var1,op); break;
     case NC_UBYTE: var_ret=Vub.var_op(var1,op); break;
-    case NC_CHAR: break; /* Do nothing */
-    case NC_STRING: break; /* Do nothing */
+    case NC_CHAR:  var_ret=Vs.var_op(var1,op); break;
+    case NC_STRING:  break; /* Do nothing */
     default: nco_dfl_case_nc_type_err(); break;
     }
     return var_ret;
@@ -1344,7 +1345,7 @@ ncap_var_var_stc
   switch (var1->type) {
   case NC_DOUBLE: var_ret=Vd.var_var_op(var1,var2,op); break;
   case NC_FLOAT: var_ret=Vf.var_var_op(var1,var2,op); break;
-  case NC_INT:var_ret=Vl.var_var_op(var1,var2,op); break;            
+  case NC_INT:var_ret=Vi.var_var_op(var1,var2,op); break;            
   case NC_SHORT: var_ret=Vs.var_var_op(var1,var2,op); break;
   case NC_USHORT: var_ret=Vus.var_var_op(var1,var2,op); break;
   case NC_UINT: var_ret=Vui.var_var_op(var1,var2,op); break;
@@ -1946,7 +1947,7 @@ ncap_cst_mk( /* [fnc] create casting var from a list of dims */
     lst_nm=str_vtr[idx].c_str();
     // Search dmn_out_vtr for dimension
     dmn_item=prs_arg->dmn_out_vtr.find(lst_nm);
-    if(dmn_item != NULL){ 
+    if(dmn_item){ 
       dmn[idx]=dmn_item;
       continue;
     }
@@ -2217,7 +2218,7 @@ ncap_sclr_var_mk(
   var_sct *var;
   var=ncap_sclr_var_mk(var_nm,(nc_type)NC_INT,true);
   (void)cast_void_nctype((nc_type)NC_INT,&var->val);
-  *var->val.lp=val_int;
+  *var->val.ip=val_int;
 
   (void)cast_nctype_void((nc_type)NC_INT,&var->val);
   return var;
@@ -2860,7 +2861,7 @@ ncap_evl_srp(
     return true;
   
   for(idx=0 ; idx < srp_vtr.size() ; idx++)
-    if( *srp_vtr[idx] != NULL_CEWI) 
+    if( *srp_vtr[idx]) 
       return false;
   
   return true;
