@@ -3,16 +3,16 @@
 
 #include <antlr/config.hpp>
 #include "ncoParserTokenTypes.hpp"
-/* $ANTLR 2.7.7 (20090306): "ncoGrammer.g" -> "ncoTree.hpp"$ */
+/* $ANTLR 2.7.7 (20091029): "ncoGrammer.g" -> "ncoTree.hpp"$ */
 #include <antlr/TreeParser.hpp>
 
 #line 1 "ncoGrammer.g"
 
-/* $Header: /cvsroot/nco/nco/src/nco++/ncoTree.hpp,v 1.89 2009/07/07 15:40:39 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco++/ncoTree.hpp,v 1.98 2010/02/06 07:19:25 zender Exp $ */
 
 /* Purpose: ANTLR Grammar and support files for ncap2 */
 
-/* Copyright (C) 2005--2009 Charlie Zender
+/* Copyright (C) 2005--2010 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -206,7 +206,7 @@ nbr_dmn=lmt_init(lmt,ast_lmt_vtr);
          (void)cast_void_nctype((nc_type)NC_INT,&var_out->val);
 
           // only interested in the first value.
-         lcl_ind[jdx]=var_out->val.lp[0];
+         lcl_ind[jdx]=var_out->val.ip[0];
 
          var_out=nco_var_free(var_out);
         }
@@ -445,6 +445,9 @@ public:
 	);
 	public: var_sct * out_asn(ANTLR_USE_NAMESPACE(antlr)RefAST _t);
 	public: var_sct * value_list(ANTLR_USE_NAMESPACE(antlr)RefAST _t);
+	public: var_sct * value_list_string(ANTLR_USE_NAMESPACE(antlr)RefAST _t,
+		 std::vector<var_sct*> &exp_vtr
+	);
 	public: bool  where_assign(ANTLR_USE_NAMESPACE(antlr)RefAST _t,
 		var_sct *var_msk
 	);
