@@ -1,11 +1,11 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncbo.c,v 1.142 2009/05/29 20:12:36 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncbo.c,v 1.149 2010/02/06 07:19:25 zender Exp $ */
 
 /* ncbo -- netCDF binary operator */
 
 /* Purpose: Compute sum, difference, product, or ratio of specified hyperslabs of specfied variables
    from two input netCDF files and output them to a single file. */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
    
    License: GNU General Public License (GPL) Version 3
    The full license text is at http://www.gnu.org/copyleft/gpl.html 
@@ -114,12 +114,13 @@ main(int argc,char **argv)
   char *opt_crr=NULL; /* [sng] String representation of current long-option name */
   char *optarg_lcl=NULL; /* [sng] Local copy of system optarg */
   
-  const char * const CVS_Id="$Id: ncbo.c,v 1.142 2009/05/29 20:12:36 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.142 $";
-  const char * const opt_sht_lst="34ACcD:d:FhL:l:Oo:p:rRt:v:X:xy:-:";
+  const char * const CVS_Id="$Id: ncbo.c,v 1.149 2010/02/06 07:19:25 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.149 $";
+  const char * const opt_sht_lst="346ACcD:d:FhL:l:Oo:p:rRt:v:X:xy:-:";
   
 #if defined(__cplusplus) || defined(PGI_CC)
   ddra_info_sct ddra_info;
+  ddra_info.flg_ddra=False;
 #else /* !__cplusplus */
   ddra_info_sct ddra_info={.MRV_flg=False,.flg_ddra=False,.lmn_nbr=0LL,.lmn_nbr_avg=0LL,.lmn_nbr_wgt=0LL,.nco_op_typ=nco_op_nil,.rnk_avg=0,.rnk_var=0,.rnk_wgt=0,.tmr_flg=nco_tmr_srt,.var_idx=0,.wgt_brd_flg=False,.wrd_sz=0};
 #endif /* !__cplusplus */
@@ -150,7 +151,6 @@ main(int argc,char **argv)
   int fll_md_old; /* [enm] Old fill mode */
   int idx;
   int jdx;
-  int kdx;
   int dmn_idx;
   int dmn_jdx;
   int in_id_1;  
@@ -293,6 +293,9 @@ main(int argc,char **argv)
     case '4': /* Catch-all to prescribe output storage format */
       if(!strcmp(opt_crr,"64bit")) fl_out_fmt=NC_FORMAT_64BIT; else fl_out_fmt=NC_FORMAT_NETCDF4; 
       break;
+    case '6': /* Request netCDF3 64-bit offset output storage format */
+      fl_out_fmt=NC_FORMAT_64BIT;
+      break;
     case 'A': /* Toggle FORCE_APPEND */
       FORCE_APPEND=!FORCE_APPEND;
       break;
@@ -376,7 +379,7 @@ main(int argc,char **argv)
       nco_exit(EXIT_FAILURE);
       break;
     } /* end switch */
-    if(opt_crr != NULL) opt_crr=(char *)nco_free(opt_crr);
+    if(opt_crr) opt_crr=(char *)nco_free(opt_crr);
   } /* end while loop */
   
   /* Process positional arguments and fill in filenames */
@@ -418,7 +421,7 @@ main(int argc,char **argv)
      int aux_idx_nbr;
      aux=nco_aux_evl(in_id_1,aux_nbr,aux_arg,&aux_idx_nbr);
      if(aux_idx_nbr > 0){
-        lmt=nco_realloc(lmt,(lmt_nbr+aux_idx_nbr)*sizeof(lmt_sct *));
+        lmt=(lmt_sct **)nco_realloc(lmt,(lmt_nbr+aux_idx_nbr)*sizeof(lmt_sct *));
         int lmt_nbr_new=lmt_nbr+aux_idx_nbr;
         int aux_idx=0;
         for(int lmt_idx=lmt_nbr;lmt_idx<lmt_nbr_new;lmt_idx++) lmt[lmt_idx]=aux[aux_idx++];
@@ -482,54 +485,20 @@ main(int argc,char **argv)
   /* Dimension lists no longer needed */
   dmn_lst_1=nco_nm_id_lst_free(dmn_lst_1,nbr_dmn_xtr_1);
   dmn_lst_2=nco_nm_id_lst_free(dmn_lst_2,nbr_dmn_xtr_2);
-  
-  /* Merge hyperslab limit information into dimension structures */
-  /* 
-  if(lmt_nbr > 0) (void)nco_dmn_lmt_mrg(dim_1,nbr_dmn_xtr_1,lmt,lmt_nbr);
-  if(lmt_nbr > 0) (void)nco_dmn_lmt_mrg(dim_2,nbr_dmn_xtr_2,lmt,lmt_nbr);
-  */
-  
-  /* Check that dims in list 2 are a subset of list 1 and that they are the same size */
-  for(idx=0 ; idx<nbr_dmn_xtr_2 ; idx++ ){
-    for(jdx=0 ; jdx<nbr_dmn_xtr_1 ; jdx++) 
-       if(!strcmp(dim_2[idx]->nm,dim_1[jdx]->nm))
-	     break;
-		 		
-	if(jdx==nbr_dmn_xtr_1) {	 	   
-     (void)fprintf(fp_stdout,"%s: ERROR dim \"%s\" in second file %s - not present in first file %s\n",prg_nm,dim_2[idx]->nm,fl_in_2,fl_in_1);
-       nco_exit(EXIT_FAILURE);
-    }  
-	
-	if(dim_2[idx]->cnt != dim_1[jdx]->cnt){
-	   if(dim_1[jdx]->is_rec_dmn)    
-	     (void)fprintf(fp_stdout,"%s: ERROR record dimension mismatch : record dim file in %s is %li : record dim file in %s is %li\n",prg_nm,fl_in_1,dim_1[jdx]->cnt, fl_in_2,dim_2[idx]->cnt);     
-	   else	      
-		 (void)fprintf(fp_stdout,"%s: ERROR dimension mismatch :  dim \"%s\" in file %s is %li : in file  %s it is %li\n",prg_nm,dim_1[jdx]->nm, fl_in_1,dim_1[jdx]->cnt, fl_in_2,dim_2[idx]->cnt);
-		nco_exit(EXIT_FAILURE); 
-	}	
-				
 
-  } /* end for idx */	
+  /* Check that dims in list 2 are a subset of list 1 and that they are the same size */
+  (void)nco_dmn_sct_cmp(dim_1,nbr_dmn_xtr_1,dim_2,nbr_dmn_xtr_2,fl_in_1,fl_in_2);    
 	  
-                                         		 		 
-				         
   /* Duplicate input dimension structures for output dimension structures */
   dmn_out=(dmn_sct **)nco_malloc(nbr_dmn_xtr_1*sizeof(dmn_sct *));
-  for(idx=0  ; idx<nbr_dmn_xtr_1 ; idx++){ 
+  for(idx=0;idx<nbr_dmn_xtr_1;idx++){ 
     dmn_out[idx]=nco_dmn_dpl(dim_1[idx]);
-    (void)nco_dmn_xrf(dim_1[idx],dmn_out[idx]); 
-    /* Merge limit from lmt_all_lst into dmn_out  */ 
-    for(jdx=0; jdx<nbr_dmn_fl_1; jdx++)
-       if(!strcmp(dmn_out[idx]->nm, lmt_all_lst[jdx]->dmn_nm)){
-         dmn_out[idx]->sz=lmt_all_lst[jdx]->dmn_cnt;
-         dmn_out[idx]->srt=0;
-         dmn_out[idx]->end=lmt_all_lst[jdx]->dmn_cnt-1;
-         dmn_out[idx]->cnt=lmt_all_lst[jdx]->dmn_cnt;
-         dmn_out[idx]->srd=1L;
-         break;
-       }
+    (void)nco_dmn_xrf(dim_1[idx],dmn_out[idx]);
   }
 
+  /* Merge hyperslab limit information into dimension structures */
+  if(nbr_dmn_fl_1 > 0) (void)nco_dmn_lmt_all_mrg(dmn_out,nbr_dmn_xtr_1,lmt_all_lst,nbr_dmn_fl_1); 
+
   if(dbg_lvl >= nco_dbg_sbr){
     for(idx=0;idx<nbr_xtr_1;idx++) (void)fprintf(stderr,"xtr_lst_1[%d].nm = %s, .id= %d\n",idx,xtr_lst_1[idx].nm,xtr_lst_1[idx].id);
   } /* end if */
@@ -544,9 +513,7 @@ main(int argc,char **argv)
     (void)nco_xrf_var(var_1[idx],var_out[idx]);
     (void)nco_xrf_dmn(var_out[idx]);
   } /* end loop over idx */
-  for(idx=0;idx<nbr_xtr_2;idx++){
-    var_2[idx]=nco_var_fll(in_id_2,xtr_lst_2[idx].id,xtr_lst_2[idx].nm,dim_2,nbr_dmn_xtr_2);
-	 } /* end loop over idx */
+  for(idx=0;idx<nbr_xtr_2;idx++) var_2[idx]=nco_var_fll(in_id_2,xtr_lst_2[idx].id,xtr_lst_2[idx].nm,dim_2,nbr_dmn_xtr_2);
 
   /* Extraction lists no longer needed */
   xtr_lst_1=nco_nm_id_lst_free(xtr_lst_1,nbr_xtr_1);
@@ -559,58 +526,26 @@ main(int argc,char **argv)
   } /* endif */
 
   /* Refresh var_out with dim_out data */
-  for(idx=0;idx<nbr_xtr_1;idx++){
-    long sz;
-    long sz_rec;
-    sz=1;
-    sz_rec=1;
-    var_sct *var_tmp;
-    var_tmp=var_out[idx];
+  (void)nco_var_dmn_refresh(var_out,nbr_xtr_1);
+
+  /* Change dimensions in dim_2 to dim_out */
+  for(idx=0;idx<nbr_dmn_xtr_2;idx++){
+    for(jdx=0;jdx<nbr_dmn_xtr_1;jdx++)  
+      if(!strcmp(dim_2[idx]->nm,dmn_out[jdx]->nm)){  
+	nco_dmn_free(dim_2[idx]);  
+	dim_2[idx]=nco_dmn_dpl(dmn_out[jdx]);
+	break;
+      } /* endif */
+    /* dimension not found so die gracefully */
+    if(jdx==nbr_dmn_xtr_1){
+      (void)fprintf(fp_stdout,"%s: ERROR dimension \"%s\" in second file %s is not present in first file %s\n",prg_nm,dim_2[idx]->nm,fl_in_2,fl_in_1);
+      nco_exit(EXIT_FAILURE);
+    } /* endif dimension not found */
+  } /* end loop over dimensions */
+
+  /* Refresh var_2 with dim_out data */
+  (void)nco_var_dmn_refresh(var_2,nbr_xtr_2);
     
-    for(jdx=0 ; jdx<var_tmp->nbr_dim ; jdx++){
-      var_tmp->srt[jdx]=var_tmp->dim[jdx]->srt; 
-      var_tmp->end[jdx]=var_tmp->dim[jdx]->end;
-      var_tmp->cnt[jdx]=var_tmp->dim[jdx]->cnt;
-      var_tmp->srd[jdx]=var_tmp->dim[jdx]->srd;
-      sz*=var_tmp->dim[jdx]->cnt;
-      if(jdx >0) sz_rec*=var_tmp->dim[jdx]->cnt;
-     }/* end loop over jdx */
-     var_tmp->sz=sz; 
-     var_tmp->sz_rec=sz_rec;
-  } /* end loop over idx */
-
-  /* Refresh var_2 with dim_out data */  
-  for(idx=0;idx<nbr_xtr_2;idx++){
-    long sz;
-    long sz_rec;
-    sz=1;
-    sz_rec=1;
-    var_sct *var_tmp;
-    var_tmp=var_2[idx];
-	
-    for(jdx=0 ; jdx<var_tmp->nbr_dim ; jdx++){
-	  for(kdx=0 ; kdx<nbr_dmn_fl_1;kdx++)
-		if(!strcmp(var_tmp->dim[jdx]->nm,dmn_out[kdx]->nm)){
-		  var_tmp->dim[jdx]=dmn_out[kdx];
-		  break;
-		}
-	  /* dim not found die gracefully */
-	  if(kdx==nbr_dmn_fl_1){
-	   (void)fprintf(fp_stdout,"%s: ERROR dim \"%s\" in second file %s - not present in first file %s\n",prg_nm,var_tmp->dim[jdx]->nm,fl_in_2,fl_in_1);
-	   nco_exit(EXIT_FAILURE);
-	  }  
-			
-      var_tmp->srt[jdx]=var_tmp->dim[jdx]->srt; 
-      var_tmp->end[jdx]=var_tmp->dim[jdx]->end;
-      var_tmp->cnt[jdx]=var_tmp->dim[jdx]->cnt;
-      var_tmp->srd[jdx]=var_tmp->dim[jdx]->srd;
-      sz*=var_tmp->dim[jdx]->cnt;
-      if(jdx >0) sz_rec*=var_tmp->dim[jdx]->cnt;
-     }/* end loop over jdx */
-     var_tmp->sz=sz; 
-     var_tmp->sz_rec=sz_rec;
-  } /* end loop over idx */
-
   /* Divide variable lists into lists of fixed variables and variables to be processed
      Create lists from file_1 last so those values remain in *_out arrays */
   (void)nco_var_lst_dvd(var_2,var_out,nbr_xtr_2,CNV_CCM_CCSM_CF,nco_pck_plc_nil,nco_pck_map_nil,(dmn_sct **)NULL,0,&var_fix_2,&var_fix_out,&nbr_var_fix_2,&var_prc_2,&var_prc_out,&nbr_var_prc_2);
@@ -621,7 +556,7 @@ main(int argc,char **argv)
 
   /* Die gracefully on unsupported features... */
   if(nbr_var_fix_1 < nbr_var_fix_2){
-    (void)fprintf(fp_stdout,"%s: ERROR First file has fewer fixed variables than second file (%d < %d). This feature is NCO TODO 581.\n",prg_nm,nbr_var_fix_1,nbr_var_fix_2);
+    (void)fprintf(fp_stdout,"%s: ERROR First file has fewer fixed variables than second file (%d < %d). This feature is TODO nco581.\n",prg_nm,nbr_var_fix_1,nbr_var_fix_2);
       nco_exit(EXIT_FAILURE);
   } /* endif */
 
@@ -815,8 +750,8 @@ main(int argc,char **argv)
   /* Clean memory unless dirty memory allowed */
   if(flg_cln){
     /* ncbo-specific memory */
-    if(fl_in_1 != NULL) fl_in_1=(char *)nco_free(fl_in_1);
-    if(fl_in_2 != NULL) fl_in_2=(char *)nco_free(fl_in_2);
+    if(fl_in_1) fl_in_1=(char *)nco_free(fl_in_1);
+    if(fl_in_2) fl_in_2=(char *)nco_free(fl_in_2);
     
     /* NCO-generic clean-up */
     /* Free individual strings/arrays */
@@ -828,17 +763,17 @@ main(int argc,char **argv)
     if(nbr_dmn_fl_1 > 0) lmt_all_lst=nco_lmt_all_lst_free(lmt_all_lst,nbr_dmn_fl_1);   
     lmt=(lmt_sct**)nco_free(lmt); 
 
-    if(cmd_ln != NULL) cmd_ln=(char *)nco_free(cmd_ln);
-    if(fl_out != NULL) fl_out=(char *)nco_free(fl_out);
-    if(fl_out_tmp != NULL) fl_out_tmp=(char *)nco_free(fl_out_tmp);
-    if(fl_pth != NULL) fl_pth=(char *)nco_free(fl_pth);
-    if(fl_pth_lcl != NULL) fl_pth_lcl=(char *)nco_free(fl_pth_lcl);
-    if(in_id_1_arr != NULL) in_id_1_arr=(int *)nco_free(in_id_1_arr);
-    if(in_id_2_arr != NULL) in_id_2_arr=(int *)nco_free(in_id_2_arr);
+    if(cmd_ln) cmd_ln=(char *)nco_free(cmd_ln);
+    if(fl_out) fl_out=(char *)nco_free(fl_out);
+    if(fl_out_tmp) fl_out_tmp=(char *)nco_free(fl_out_tmp);
+    if(fl_pth) fl_pth=(char *)nco_free(fl_pth);
+    if(fl_pth_lcl) fl_pth_lcl=(char *)nco_free(fl_pth_lcl);
+    if(in_id_1_arr) in_id_1_arr=(int *)nco_free(in_id_1_arr);
+    if(in_id_2_arr) in_id_2_arr=(int *)nco_free(in_id_2_arr);
     /* Free lists of strings */
-    if(fl_lst_in != NULL && fl_lst_abb == NULL) fl_lst_in=nco_sng_lst_free(fl_lst_in,fl_nbr); 
-    if(fl_lst_in != NULL && fl_lst_abb != NULL) fl_lst_in=nco_sng_lst_free(fl_lst_in,1);
-    if(fl_lst_abb != NULL) fl_lst_abb=nco_sng_lst_free(fl_lst_abb,abb_arg_nbr);
+    if(fl_lst_in && fl_lst_abb == NULL) fl_lst_in=nco_sng_lst_free(fl_lst_in,fl_nbr); 
+    if(fl_lst_in && fl_lst_abb) fl_lst_in=nco_sng_lst_free(fl_lst_in,1);
+    if(fl_lst_abb) fl_lst_abb=nco_sng_lst_free(fl_lst_abb,abb_arg_nbr);
     if(var_lst_in_nbr > 0) var_lst_in=nco_sng_lst_free(var_lst_in,var_lst_in_nbr);
     /* Free limits */
     for(idx=0;idx<lmt_nbr;idx++) lmt_arg[idx]=(char *)nco_free(lmt_arg[idx]);
@@ -847,8 +782,10 @@ main(int argc,char **argv)
     if(aux_nbr > 0) aux=(lmt_sct **)nco_free(aux);
     /* Free dimension lists */
     if(nbr_dmn_xtr_1 > 0) dim_1=nco_dmn_lst_free(dim_1,nbr_dmn_xtr_1);
-    if(nbr_dmn_xtr_2 > 0) dim_2=nco_dmn_lst_free(dim_2,nbr_dmn_xtr_2);
     if(nbr_dmn_xtr_1 > 0) dmn_out=nco_dmn_lst_free(dmn_out,nbr_dmn_xtr_1);
+    if(nbr_dmn_xtr_2 > 0) dim_2=nco_dmn_lst_free(dim_2,nbr_dmn_xtr_2);
+
+
     /* Free variable lists 
        Using nco_var_lst_free() to free main var_1 and var_2 lists would fail
        if ncap_var_prc_dmn() had to broadcast any variables because pointer
