@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncflint.c,v 1.165 2009/05/29 20:12:36 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncflint.c,v 1.171 2010/01/26 13:06:25 zender Exp $ */
 
 /* ncflint -- netCDF file interpolator */
 
 /* Purpose: Linearly interpolate a third netCDF file from two input files */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
 
    License: GNU General Public License (GPL) Version 3
    The full license text is at http://www.gnu.org/copyleft/gpl.html 
@@ -103,12 +103,13 @@ main(int argc,char **argv)
   char *opt_crr=NULL; /* [sng] String representation of current long-option name */
   char *optarg_lcl=NULL; /* [sng] Local copy of system optarg */
 
-  const char * const CVS_Id="$Id: ncflint.c,v 1.165 2009/05/29 20:12:36 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.165 $";
-  const char * const opt_sht_lst="34ACcD:d:Fhi:L:l:Oo:p:rRt:v:X:xw:-:";
+  const char * const CVS_Id="$Id: ncflint.c,v 1.171 2010/01/26 13:06:25 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.171 $";
+  const char * const opt_sht_lst="346ACcD:d:Fhi:L:l:Oo:p:rRt:v:X:xw:-:";
   
 #if defined(__cplusplus) || defined(PGI_CC)
   ddra_info_sct ddra_info;
+  ddra_info.flg_ddra=False;
 #else /* !__cplusplus */
   ddra_info_sct ddra_info={.flg_ddra=False};
 #endif /* !__cplusplus */
@@ -279,6 +280,9 @@ main(int argc,char **argv)
     case '4': /* Catch-all to prescribe output storage format */
       if(!strcmp(opt_crr,"64bit")) fl_out_fmt=NC_FORMAT_64BIT; else fl_out_fmt=NC_FORMAT_NETCDF4; 
       break;
+    case '6': /* Request netCDF3 64-bit offset output storage format */
+      fl_out_fmt=NC_FORMAT_64BIT;
+      break;
     case 'A': /* Toggle FORCE_APPEND */
       FORCE_APPEND=!FORCE_APPEND;
       break;
@@ -387,8 +391,10 @@ main(int argc,char **argv)
       nco_exit(EXIT_FAILURE);
       break;
     } /* end switch */
-    if(opt_crr != NULL) opt_crr=(char *)nco_free(opt_crr);
+    if(opt_crr) opt_crr=(char *)nco_free(opt_crr);
   } /* end while loop */
+
+
   
   if(CMD_LN_NTP_VAR && CMD_LN_NTP_WGT){
     (void)fprintf(stdout,"%s: ERROR interpolating variable (-i) and fixed weight(s) (-w) both set\n",prg_nm_get());
@@ -437,7 +443,7 @@ main(int argc,char **argv)
      int aux_idx_nbr;
      aux=nco_aux_evl(in_id_1,aux_nbr,aux_arg,&aux_idx_nbr);
      if(aux_idx_nbr > 0){
-        lmt=nco_realloc(lmt,(lmt_nbr+aux_idx_nbr)*sizeof(lmt_sct *));
+        lmt=(lmt_sct **)nco_realloc(lmt,(lmt_nbr+aux_idx_nbr)*sizeof(lmt_sct *));
         int lmt_nbr_new=lmt_nbr+aux_idx_nbr;
         int aux_idx=0;
         for(int lmt_idx=lmt_nbr;lmt_idx<lmt_nbr_new;lmt_idx++) lmt[lmt_idx]=aux[aux_idx++];
@@ -488,27 +494,19 @@ main(int argc,char **argv)
 
   /* Dimension list no longer needed */
   dmn_lst=nco_nm_id_lst_free(dmn_lst,nbr_dmn_xtr);
-  
-  /* Merge hyperslab limit information into dimension structures */
-  /* if(lmt_nbr > 0) (void)nco_dmn_lmt_mrg(dim,nbr_dmn_xtr,lmt,lmt_nbr); */
+ 
 
   /* Duplicate input dimension structures for output dimension structures */
   dmn_out=(dmn_sct **)nco_malloc(nbr_dmn_xtr*sizeof(dmn_sct *));
   for(idx=0  ; idx<nbr_dmn_xtr ; idx++){ 
     dmn_out[idx]=nco_dmn_dpl(dim[idx]);
-    (void)nco_dmn_xrf(dim[idx],dmn_out[idx]); 
-    /* Merge limit from lmt_all_lst into dmn_out  */ 
-    for(jdx=0; jdx<nbr_dmn_fl; jdx++)
-       if(!strcmp(dmn_out[idx]->nm, lmt_all_lst[jdx]->dmn_nm)){
-         dmn_out[idx]->sz=lmt_all_lst[jdx]->dmn_cnt;
-         dmn_out[idx]->srt=0;
-         dmn_out[idx]->end=lmt_all_lst[jdx]->dmn_cnt-1;
-         dmn_out[idx]->cnt=lmt_all_lst[jdx]->dmn_cnt;
-         dmn_out[idx]->srd=1L;
-         break;
-       }
+    (void)nco_dmn_xrf(dim[idx],dmn_out[idx]);
   }
 
+  /* Merge hyperslab limit information into dimension structures */
+  if(nbr_dmn_fl > 0) (void)nco_dmn_lmt_all_mrg(dmn_out,nbr_dmn_xtr,lmt_all_lst,nbr_dmn_fl); 
+
+
   /* Fill in variable structure list for all extracted variables */
   var=(var_sct **)nco_malloc(nbr_xtr*sizeof(var_sct *));
   var_out=(var_sct **)nco_malloc(nbr_xtr*sizeof(var_sct *));
@@ -521,21 +519,9 @@ main(int argc,char **argv)
   /* Extraction list no longer needed */
   xtr_lst=nco_nm_id_lst_free(xtr_lst,nbr_xtr);
 
+
   /* Refresh var_out with dim_out data */
-  for(idx=0;idx<nbr_xtr;idx++){
-    var_sct *var_tmp;
-    long sz;
-    sz=1;
-    var_tmp=var_out[idx];
-    for(jdx=0 ; jdx<var_tmp->nbr_dim ; jdx++){
-      var_tmp->srt[jdx]=var_tmp->dim[jdx]->srt; 
-      var_tmp->end[jdx]=var_tmp->dim[jdx]->end;
-      var_tmp->cnt[jdx]=var_tmp->dim[jdx]->cnt;
-      var_tmp->srd[jdx]=var_tmp->dim[jdx]->srd;
-      sz*=var_tmp->dim[jdx]->cnt;
-     } /* end loop over jdx */
-     var_tmp->sz=sz;  
-  } /* end loop over idx */
+  (void)nco_var_dmn_refresh(var_out,nbr_xtr);
 
 
     /* Divide variable lists into lists of fixed variables and variables to be processed */
@@ -630,9 +616,9 @@ main(int argc,char **argv)
     (void)nco_var_dvd(wgt_1->type,wgt_1->sz,wgt_1->has_mss_val,wgt_1->mss_val,ntp_2->val,wgt_1->val);
     (void)nco_var_dvd(wgt_2->type,wgt_2->sz,wgt_2->has_mss_val,wgt_2->mss_val,ntp_2->val,wgt_2->val);
 
-    if(ntp_1 != NULL) ntp_1=nco_var_free(ntp_1);
-    if(ntp_2 != NULL) ntp_2=nco_var_free(ntp_2);
-    if(ntp_var_out != NULL) ntp_var_out=nco_var_free(ntp_var_out);
+    if(ntp_1) ntp_1=nco_var_free(ntp_1);
+    if(ntp_2) ntp_2=nco_var_free(ntp_2);
+    if(ntp_var_out) ntp_var_out=nco_var_free(ntp_var_out);
   } /* end if CMD_LN_NTP_VAR */
 
   if(CMD_LN_NTP_WGT){
@@ -713,9 +699,9 @@ main(int argc,char **argv)
     } /* end OpenMP critical */
     
     /* Free dynamically allocated buffers */
-    if(var_prc_1[idx] != NULL) var_prc_1[idx]=nco_var_free(var_prc_1[idx]);
-    if(var_prc_2[idx] != NULL) var_prc_2[idx]=nco_var_free(var_prc_2[idx]);
-    if(var_prc_out[idx] != NULL) var_prc_out[idx]=nco_var_free(var_prc_out[idx]);
+    if(var_prc_1[idx]) var_prc_1[idx]=nco_var_free(var_prc_1[idx]);
+    if(var_prc_2[idx]) var_prc_2[idx]=nco_var_free(var_prc_2[idx]);
+    if(var_prc_out[idx]) var_prc_out[idx]=nco_var_free(var_prc_out[idx]);
     
   } /* end (OpenMP parallel for) loop over idx */
   if(dbg_lvl >= nco_dbg_var) (void)fprintf(stderr,"\n");
@@ -734,14 +720,14 @@ main(int argc,char **argv)
   /* Clean memory unless dirty memory allowed */
   if(flg_cln){
     /* ncflint-specific memory */
-    if(fl_in_1 != NULL) fl_in_1=(char *)nco_free(fl_in_1);
-    if(fl_in_2 != NULL) fl_in_2=(char *)nco_free(fl_in_2);
+    if(fl_in_1) fl_in_1=(char *)nco_free(fl_in_1);
+    if(fl_in_2) fl_in_2=(char *)nco_free(fl_in_2);
     var_prc_1=(var_sct **)nco_free(var_prc_1);
     var_prc_2=(var_sct **)nco_free(var_prc_2);
-    if(wgt_1 != NULL) wgt_1=(var_sct *)nco_var_free(wgt_1);
-    if(wgt_2 != NULL) wgt_2=(var_sct *)nco_var_free(wgt_2);
-    if(wgt_out_1 != NULL) wgt_out_1=(var_sct *)nco_var_free(wgt_out_1);
-    if(wgt_out_2 != NULL) wgt_out_2=(var_sct *)nco_var_free(wgt_out_2);
+    if(wgt_1) wgt_1=(var_sct *)nco_var_free(wgt_1);
+    if(wgt_2) wgt_2=(var_sct *)nco_var_free(wgt_2);
+    if(wgt_out_1) wgt_out_1=(var_sct *)nco_var_free(wgt_out_1);
+    if(wgt_out_2) wgt_out_2=(var_sct *)nco_var_free(wgt_out_2);
 
     /* free lmt[] nb is now referenced within lmt_all_lst[idx]  */
     for(idx=0; idx<nbr_dmn_fl;idx++)
@@ -754,17 +740,17 @@ main(int argc,char **argv)
 
     /* NCO-generic clean-up */
     /* Free individual strings/arrays */
-    if(cmd_ln != NULL) cmd_ln=(char *)nco_free(cmd_ln);
-    if(fl_out != NULL) fl_out=(char *)nco_free(fl_out);
-    if(fl_out_tmp != NULL) fl_out_tmp=(char *)nco_free(fl_out_tmp);
-    if(fl_pth != NULL) fl_pth=(char *)nco_free(fl_pth);
-    if(fl_pth_lcl != NULL) fl_pth_lcl=(char *)nco_free(fl_pth_lcl);
-    if(in_id_1_arr != NULL) in_id_1_arr=(int *)nco_free(in_id_1_arr);
-    if(in_id_2_arr != NULL) in_id_2_arr=(int *)nco_free(in_id_2_arr);
+    if(cmd_ln) cmd_ln=(char *)nco_free(cmd_ln);
+    if(fl_out) fl_out=(char *)nco_free(fl_out);
+    if(fl_out_tmp) fl_out_tmp=(char *)nco_free(fl_out_tmp);
+    if(fl_pth) fl_pth=(char *)nco_free(fl_pth);
+    if(fl_pth_lcl) fl_pth_lcl=(char *)nco_free(fl_pth_lcl);
+    if(in_id_1_arr) in_id_1_arr=(int *)nco_free(in_id_1_arr);
+    if(in_id_2_arr) in_id_2_arr=(int *)nco_free(in_id_2_arr);
     /* Free lists of strings */
-    if(fl_lst_in != NULL && fl_lst_abb == NULL) fl_lst_in=nco_sng_lst_free(fl_lst_in,fl_nbr); 
-    if(fl_lst_in != NULL && fl_lst_abb != NULL) fl_lst_in=nco_sng_lst_free(fl_lst_in,1);
-    if(fl_lst_abb != NULL) fl_lst_abb=nco_sng_lst_free(fl_lst_abb,abb_arg_nbr);
+    if(fl_lst_in && fl_lst_abb == NULL) fl_lst_in=nco_sng_lst_free(fl_lst_in,fl_nbr); 
+    if(fl_lst_in && fl_lst_abb) fl_lst_in=nco_sng_lst_free(fl_lst_in,1);
+    if(fl_lst_abb) fl_lst_abb=nco_sng_lst_free(fl_lst_abb,abb_arg_nbr);
     if(var_lst_in_nbr > 0) var_lst_in=nco_sng_lst_free(var_lst_in,var_lst_in_nbr);
     /* Free limits */
     for(idx=0;idx<lmt_nbr;idx++) lmt_arg[idx]=(char *)nco_free(lmt_arg[idx]);
