@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnf_typ.h,v 1.29 2009/05/22 16:22:51 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnf_typ.h,v 1.31 2010/01/29 14:31:16 hmb Exp $ */
 
 /* Purpose: Conform variable types */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -70,6 +70,13 @@ nco_scv_cnf_typ /* [fnc] Convert scalar attribute to typ_new using C implicit co
 (const nc_type typ_new, /* I [enm] Type to convert scv_old to */
  scv_sct * const scv_old); /* I/O [sct] Scalar value to convert */
 
+
+nc_type /* O [enm] Return Highest type */
+ncap_typ_hgh /* [fnc] Promote variable to higher common precision */
+(nc_type typ_1,  /* I [enm] type */
+ nc_type typ_2); /* I [enm] type */
+
+
 nc_type /* O [enm] Highest precision of input variables */
 ncap_var_retype /* [fnc] Promote variable to higher common precision */
 (var_sct *var_1, /* I/O [sct] Variable */
