@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.18 2009/06/14 20:47:42 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.25 2010/01/15 00:57:18 zender Exp $ */
 
 /* Purpose: NCO utilities for chunking */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -23,7 +23,10 @@
 
    ncecat testing:
    ncecat -O -4 -D 4 --cnk_plc=all -p ~/nco/data in.nc in.nc ~/foo.nc
-   ncecat -O -4 -D 4 --cnk_plc=g2d --cnk_map=rd1 --cnk_dmn lat,64 --cnk_dmn lon,128 -p ${DATA}/dstmch90 dstmch90_clm.nc dstmch90_clm.nc ~/foo.nc */
+   ncecat -O -4 -D 4 --cnk_plc=g2d --cnk_map=rd1 --cnk_dmn lat,64 --cnk_dmn lon,128 -p ${DATA}/dstmch90 dstmch90_clm.nc dstmch90_clm.nc ~/foo.nc
+
+   Advanced Chunking:
+   http://hdfeos.org/workshops/ws13/presentations/day1/HDF5-EOSXIII-Advanced-Chunking.ppt */
 
 #include "nco_cnk.h" /* Chunking */
 
@@ -216,6 +219,8 @@ nco_cnk_sz_set /* [fnc] Set chunksize parameters */
   int dmn_idx;
   int cnk_map; /* [enm] Chunking map */
   int cnk_plc; /* [enm] Chunking policy */
+  int chk_typ; /* [enm] Checksum type */
+  int deflate; /* [enm] Deflate filter is on */
   int dmn_nbr; /* [nbr] Number of dimensions in variable */
   int fl_fmt; /* [enm] Input file format */
   int lmt_idx;
@@ -229,6 +234,11 @@ nco_cnk_sz_set /* [fnc] Set chunksize parameters */
   long dmn_sz;
 
   nco_bool flg_cnk=False; /* [flg] Chunking requested */
+  nco_bool is_rec_var; /* [flg] Record variable */
+  nco_bool is_chk_var; /* [flg] Checksummed variable */
+  nco_bool is_cmp_var; /* [flg] Compressed variable */
+  nco_bool is_chunked; /* [flg] Chunked variable */
+  nco_bool must_be_chunked; /* [flg] Variable must be chunked */
 
   nc_type var_typ_dsk;
   
@@ -291,47 +301,82 @@ nco_cnk_sz_set /* [fnc] Set chunksize parameters */
 	break;
       } /* end if */
     } /* end loop over limit */
-  } /* endif */
+  } /* NCO_REC_DMN_UNDEFINED */
 
   /* NB: Assumes variable IDs range from [0..var_nbr-1] */
   for(var_idx=0;var_idx<var_nbr;var_idx++){
 
     /* Initialize storage type for this variable */
     srg_typ=NC_CONTIGUOUS; /* [enm] Storage type */
-    cnk_sz=NULL; /* [nbr] Chunksize list */
+    cnk_sz=(size_t *)NULL; /* [nbr] Chunksize list */
+    is_rec_var=False; /* [flg] Record variable */
+    is_chk_var=False; /* [flg] Checksummed variable */
+    is_cmp_var=False; /* [flg] Compressed variable */
+    is_chunked=False; /* [flg] Chunked variable */
 
     /* Get type and number of dimensions for variable */
     (void)nco_inq_var(nc_id,var_idx,var_nm,&var_typ_dsk,&dmn_nbr,(int *)NULL,(int *)NULL);
     
     if(dmn_nbr == 0) continue; /* Skip chunking calls for scalars */
 
+    /* Allocate space to hold dimension IDs */
+    dmn_id=(int *)nco_malloc(dmn_nbr*sizeof(int));
+    /* Get dimension IDs */
+    (void)nco_inq_vardimid(nc_id,var_idx,dmn_id);
+    
+    /* Is this a record variable? */
+    if(rcd_dmn_id != NCO_REC_DMN_UNDEFINED){
+      for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
+	/* Is this the record dimension? */
+	if(dmn_id[dmn_idx] == rcd_dmn_id) break; /* ...then search no further */
+      } /* end loop over dmn */
+      if(dmn_idx < dmn_nbr) is_rec_var=True; /* [flg] Record variable */
+    } /* NCO_REC_DMN_UNDEFINED */
+
+    /* Is variable compressed? */
+    (void)nco_inq_var_deflate(nc_id,var_idx,NULL,&deflate,NULL);
+    if(deflate) is_cmp_var=True; 
+    
+    /* Is variable checksummed? */
+    (void)nco_inq_var_fletcher32(nc_id,var_idx,&chk_typ);
+    if(chk_typ != NC_NOCHECKSUM) is_chk_var=True;
+
+    /* Must variable be chunked? */
+    if(is_rec_var || is_chk_var || is_cmp_var) must_be_chunked=True; else must_be_chunked=False;
+
+    /* Is variable currently chunked? */
+    is_chunked=nco_cnk_dsk_inq(nc_id,var_idx);
+
     /* Explicitly turn off chunking for arrays that are... */
     if((cnk_plc == nco_cnk_plc_g2d && dmn_nbr < 2) || /* ...much too small... */
        (cnk_plc == nco_cnk_plc_g3d && dmn_nbr < 3) || /* ...too small... */
        (cnk_plc == nco_cnk_plc_uck) || /* ...intentionally unchunked... */
        False){
-      /* Turn chunking off for this variable */
-      if(nco_cnk_dsk_inq(nc_id,var_idx)){
-	if(dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s unchunking %s\n",prg_nm_get(),fnc_nm,var_nm);
-	(void)nco_def_var_chunking(nc_id,var_idx,srg_typ,cnk_sz);
+      /* If variable is chunked */
+      if(is_chunked){
+	if(must_be_chunked){
+	  if(dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s %s must be chunked (record, compressed, or checksummed variable)\n",prg_nm_get(),fnc_nm,var_nm);
+	}else{
+	  /* Turn off chunking for this variable */
+	  if(dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s unchunking %s\n",prg_nm_get(),fnc_nm,var_nm);
+	  (void)nco_def_var_chunking(nc_id,var_idx,srg_typ,cnk_sz);
+	} /* !must_be_chunked */
       }else{ /* !chunked */
 	if(dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s not unchunking %s because it is not chunked\n",prg_nm_get(),fnc_nm,var_nm);
       } /* !chunked */
+      /* Free space holding dimension IDs before skipping to next variable */
+      dmn_id=(int *)nco_free(dmn_id);
       /* Skip to next variable in loop */
       continue;
     } /* end if */
 
     /* Variable will definitely be chunked */
     srg_typ=NC_CHUNKED; /* [enm] Storage type */
+    if(dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s %schunking %s\n",prg_nm_get(),fnc_nm,(is_chunked ? "re-" : "" ),var_nm);
 
-    /* Allocate space to hold dimension IDs */
-    dmn_id=(int *)nco_malloc(dmn_nbr*sizeof(int));
     /* Allocate space to hold chunksizes */
     cnk_sz=(size_t *)nco_malloc(dmn_nbr*sizeof(size_t));
     
-    /* Get dimension IDs */
-    (void)nco_inq_vardimid(nc_id,var_idx,dmn_id);
-    
     /* Default "equal" chunksize for each dimension */
     cnk_sz_dfl=cnk_sz_scl;
     if(cnk_map == nco_cnk_map_prd){
@@ -349,7 +394,7 @@ nco_cnk_sz_set /* [fnc] Set chunksize parameters */
       /* Get dimension name and size */
       (void)nco_inq_dim(nc_id,dmn_id[dmn_idx],dmn_nm,&dmn_sz);
       
-      /* Is this a record dimension? */
+      /* Is this the record dimension? */
       if(dmn_id[dmn_idx] == rcd_dmn_id){
 	/* Does policy specify record dimension treatment? */
 	if(cnk_map == nco_cnk_map_rd1){
@@ -521,8 +566,7 @@ nco_cnk_dsk_inq /* [fnc] Check whether variable is chunked on disk */
 (const int nc_id, /* I [idx] netCDF file ID */
  const int var_id) /* I [id] Variable ID */
 {
-  /* Purpose: Check whether variable is chunked on disk and set variable members 
-     cnk_dsk and cnk_sz accordingly */
+  /* Purpose: Check whether variable is chunked on disk */
   /* ncea -O -D 3 -v cnk ~/nco/data/in.nc ~/nco/data/foo.nc */
   
   int rcd; /* [rcd] Return success code */
