@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_dmn_utl.h,v 1.27 2009/05/23 00:04:41 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_dmn_utl.h,v 1.30 2010/01/05 20:02:17 zender Exp $ */
 
 /* Purpose: Dimension utilities */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -68,6 +68,15 @@ nco_dmn_lmt_mrg /* [fnc] Merge limit structure information into dimension struct
  CST_X_PTR_CST_PTR_CST_Y(lmt_sct,lmt), /* I [sct] Dimension limit information */
  const int lmt_nbr); /* I [nbr] Number of dimensions with user-specified limits */
 
+
+void
+nco_dmn_lmt_all_mrg /* [fnc] Merge limit structure information into dimension structures */
+(dmn_sct ** const dmn, /* I [sct] Dimension structures to modify */
+ const int nbr_dmn, /* I [nbr] Number of dimension structures in structure list */
+ CST_X_PTR_CST_PTR_CST_Y(lmt_all_sct,lmt_all_lst), /* I [sct] Dimension limit information */
+ const int lmt_nbr); /* I [nbr] Number of dimensions with user-specified limits */
+
+
 dmn_sct ** /* O [sct] Pointer to free'd structure list */
 nco_dmn_lst_free /* [fnc] Free memory associated with dimension structure list */
 (dmn_sct **dmn_lst, /* I/O [sct] Dimension structure list to free */
@@ -91,6 +100,18 @@ nco_dmn_xrf  /* [fnc] Crossreference xrf elements of dimension structures */
 (dmn_sct * const dmn_1, /* I/O [sct] Dimension structure */
  dmn_sct * const dmn_2); /* I/O [sct] Dimension structure */
 
+
+void 
+nco_dmn_sct_cmp   /* [fnc] Check that dims in list 2 are a subset of list 1 and that they are the same size */
+(dmn_sct ** const dim_1, /* I [sct] Dimension list 1 */
+ const int nbr_dmn_1,  /* I [nbr] Number of dimension structures in structure list */
+ dmn_sct **const dim_2,  /* I [sct] Dimension list 1 */
+ const int nbr_dmn_2,  /* I [nbr] Number of dimension structures in structure list */
+ const char* const fl_sng_1, /* I [sng] Name of first file */
+ const char *fl_sng_2);     /* I [sng] Name of second file */
+
+
+
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
