@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_typ.h,v 1.25 2009/07/12 19:42:53 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_typ.h,v 1.28 2010/01/27 09:36:31 zender Exp $ */
 
 /* Purpose: Type definitions, opaque types */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -263,8 +263,9 @@ typedef unsigned short nco_ushort; /* [typ] NC_USHORT */
 /* NC_INT handling */
 #ifndef NCO_INT
 /* Valid options are NCO_TYP_INT, NCO_TYP_LONG
-   Default is NCO_TYP_LONG, which treats NC_INT as C-type long */
-# define NCO_INT NCO_TYP_LONG
+   Before 20091030, default was NCO_TYP_LONG, which treats NC_INT as C-type long
+   Since  20091030, default is  NCO_TYP_INT,  which treats NC_INT as C-type int */
+# define NCO_INT NCO_TYP_INT
 #endif /* NCO_INT */
 #if NCO_INT == NCO_TYP_INT
 /* Treat NC_INT as C-type int */
