@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_lst.c,v 1.83 2009/04/19 23:17:04 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_lst.c,v 1.88 2010/02/05 11:33:42 hmb Exp $ */
 
 /* Purpose: Variable list utilities */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -242,6 +242,78 @@ nco_var_lst_xcl /* [fnc] Convert exclusion list to extraction list */
   return xtr_lst;
 } /* end nco_var_lst_xcl() */
 
+nco_bool /* [flg] Variable is listed in a "coordinates" attribute */
+nco_is_spc_in_crd_att /* [fnc] Variable is listed in a "coordinates" attribute */
+(const int nc_id, /* I [id] netCDF file ID */
+ const int var_trg_id) /* I [id] Variable ID */
+{
+  /* Purpose: Is variable specified in a "coordinates" attribute?
+     If so, it may be a "multi-dimensional coordinate" that should
+     undergo special treatment by arithmetic operators. */
+  nco_bool IS_SPC_IN_CRD_ATT=False; /* [flg] Variable is listed in a "coordinates" attribute  */
+
+  const char dlm_sng[]=" "; /* [sng] Delimiter string */
+  const char fnc_nm[]="nco_is_spc_in_crd_att()"; /* [sng] Function name */
+  char **crd_lst; /* [sng] 1D array of list elements */
+  char *att_val;
+  char att_nm[NC_MAX_NAME];
+  char var_nm[NC_MAX_NAME];
+  char var_trg_nm[NC_MAX_NAME];
+  int idx_att;
+  int idx_crd;
+  int idx_var;
+  int nbr_att;
+  int nbr_crd; /* [nbr] Number of coordinates specified in "coordinates" attribute */
+  int nbr_var; /* [nbr] Number of variables in file */
+  int rcd;
+  int var_id; /* [id] Variable ID */
+  long att_sz;
+  nc_type att_typ;
+  
+  /* May need variable name for later comparison to "coordinates" attribute */
+  rcd=nco_inq_varname(nc_id,var_trg_id,var_trg_nm);
+  rcd=nco_inq_nvars(nc_id,&nbr_var);
+
+  for(idx_var=0;idx_var<nbr_var;idx_var++){
+    /* This assumption, praise the Lord, is valid in netCDF2, netCDF3, and netCDF4 */
+    var_id=idx_var;
+    
+    /* Find number of attributes */
+    rcd+=nco_inq_varnatts(nc_id,var_id,&nbr_att);
+    for(idx_att=0;idx_att<nbr_att;idx_att++){
+      rcd+=nco_inq_attname(nc_id,var_id,idx_att,att_nm);
+      /* Is attribute part of CF convention? */
+      if(!strcmp(att_nm,"coordinates")){
+	/* Yes, get list of specified attributes */
+	rcd+=nco_inq_att(nc_id,var_id,att_nm,&att_typ,&att_sz);
+	if(att_typ != NC_CHAR){
+	  rcd=nco_inq_varname(nc_id,var_id,var_nm);
+	  (void)fprintf(stderr,"%s: WARNING the \"%s\" attribute for variable %s is type %s, not %s. This violates the CF convention for specifying additional attributes. Therefore %s will skip this attribute.\n",prg_nm_get(),att_nm,var_nm,nco_typ_sng(att_typ),nco_typ_sng(NC_CHAR),fnc_nm);
+	  return IS_SPC_IN_CRD_ATT;
+	} /* end if */
+	att_val=(char *)nco_malloc((att_sz+1L)*sizeof(char));
+	if(att_sz > 0) rcd=nco_get_att(nc_id,var_id,att_nm,(void *)att_val,NC_CHAR);	  
+	/* NUL-terminate attribute */
+	att_val[att_sz]='\0';
+	/* Split list into separate coordinate names
+	   Use nco_lst_prs_sgl_2D() not nco_lst_prs_2D() to avert TODO nco944 */
+	crd_lst=nco_lst_prs_sgl_2D(att_val,dlm_sng,&nbr_crd);
+	/* ...for each coordinate in "coordinates" attribute... */
+	for(idx_crd=0;idx_crd<nbr_crd;idx_crd++){
+	  /* Does variable match name specified in coordinate list? */
+	  if(!strcmp(var_trg_nm,crd_lst[idx_crd])) break;
+	} /* end loop over coordinates in list */
+	if(idx_crd!=nbr_crd) IS_SPC_IN_CRD_ATT=True;
+	/* Free allocated memory */
+	att_val=(char *)nco_free(att_val);
+	crd_lst=nco_sng_lst_free(crd_lst,nbr_crd);
+      } /* !coordinates */
+    } /* end loop over attributes */
+  } /* end loop over idx_var */
+  
+  return IS_SPC_IN_CRD_ATT; /* [flg] Variable is listed in a "coordinates" attribute  */
+} /* end nco_is_spc_in_crd_att() */
+
 nm_id_sct * /* O [sct] Extraction list */
 nco_var_lst_crd_add /* [fnc] Add all coordinates to extraction list */
 (const int nc_id, /* I [id] netCDF file ID */
@@ -286,7 +358,7 @@ nco_var_lst_crd_add /* [fnc] Add all coordinates to extraction list */
   } /* end loop over idx */
   
   /* Detect and apply coordinates specified by CF convention
-     http://www.cgd.ucar.edu/cms/eaton/cf-metadata/CF-1.0.html#grid_ex2 */
+     http://cf-pcmdi.llnl.gov/documents/cf-conventions/1.1/cf-conventions.html#coordinate-system */
   if(CNV_CCM_CCSM_CF){
     const char dlm_sng[]=" "; /* [sng] Delimiter string */
     const char fnc_nm[]="nco_var_lst_crd_add()"; /* [sng] Function name */
@@ -721,7 +793,32 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
     if(CNV_CCM_CCSM_CF){
       if(!strcmp(var_nm,"ntrm") || !strcmp(var_nm,"ntrn") || !strcmp(var_nm,"ntrk") || !strcmp(var_nm,"ndbase") || !strcmp(var_nm,"nsbase") || !strcmp(var_nm,"nbdate") || !strcmp(var_nm,"nbsec") || !strcmp(var_nm,"mdt") || !strcmp(var_nm,"mhisf")) var_op_typ[idx]=fix;
       /* NB: all !strcmp()'s except "msk_" which uses strstr() */
-      if(prg_id == ncbo && (!strcmp(var_nm,"hyam") || !strcmp(var_nm,"hybm") || !strcmp(var_nm,"hyai") || !strcmp(var_nm,"hybi") || !strcmp(var_nm,"gw") || !strcmp(var_nm,"lon_bnds") || !strcmp(var_nm,"lat_bnds") || !strcmp(var_nm,"area") || !strcmp(var_nm,"ORO") || !strcmp(var_nm,"date") || !strcmp(var_nm,"datesec") || (strstr(var_nm,"msk_") == var_nm))) var_op_typ[idx]=fix;
+      if(nco_is_rnk_prs_rth_opr(prg_id) && (!strcmp(var_nm,"hyam") || !strcmp(var_nm,"hybm") || !strcmp(var_nm,"hyai") || !strcmp(var_nm,"hybi") || !strcmp(var_nm,"gw") || !strcmp(var_nm,"lon_bnds") || !strcmp(var_nm,"lat_bnds") || !strcmp(var_nm,"area") || !strcmp(var_nm,"ORO") || !strcmp(var_nm,"date") || !strcmp(var_nm,"datesec") || (strstr(var_nm,"msk_") == var_nm))) var_op_typ[idx]=fix;
+      /* Known "multi-dimensional coordinates" in CCSM-like model output:
+	 lat, lon, lev are normally 1-D coordinates
+	 Known exceptions:
+	 lat and lon are "2-D coordinates" in NARCCAP output
+	 NARCCAP specifies lat and lon in "coordinates" attribute of 2-D fields
+	 latixy and longxy are "2-D coordinates" in CLM output
+	 CLM does not specify latixy and longxy in "coordinates" attribute of any fields
+	 NARCCAP output gives all "coordinate-like" fields an "axis" attribute
+	 This includes time, which both ncra and ncwa _should_ process
+	 CLM does not give an "axis" attribute to any fields
+	 One method of chasing down all "coordinate-like" fields is to look
+	 for the field name in the "coordinates" attribute of any variable.
+	 However, this will miss the case when no variables use an N-D 
+	 coordinate-like variable as a coordinate.
+	 "coordinate-like" variables that should be "fixed", and not
+	 differenced, interpolated, or ensemble-averaged, include those 
+	 satisfying these conditions:
+	 0. Traditional coordinate (1-D variable same name as its dimension)
+	 1. Present in a "coordinates" attribute
+	 2. Contain an "axis" attribute (except "time")
+	 3. Found in empirical list of variables */
+      /* Check condition #1 from above: */
+      if(nco_is_rnk_prs_rth_opr(prg_id) && nco_is_spc_in_crd_att(var[idx]->nc_id,var[idx]->id)) var_op_typ[idx]=fix;
+      /* Check condition #3 from above: */
+      if(nco_is_rnk_prs_rth_opr(prg_id) && (!strcmp(var_nm,"lat") || !strcmp(var_nm,"lon") || !strcmp(var_nm,"lev") || !strcmp(var_nm,"longxy") || !strcmp(var_nm,"latixy") )) var_op_typ[idx]=fix;
     } /* end if CNV_CCM_CCSM_CF */
 
     /* Warn about any expected weird behavior */
@@ -869,10 +966,16 @@ nco_var_lst_mrg /* [fnc] Merge two variable lists into same order */
 
   /* Asymmetric lists */
   if(*var_nbr_2 > *var_nbr_1){
-    (void)fprintf(stderr,"%s: WARNING %s detects that file two has more variables than file one. The following variables, present only in file two, will not be present in the output file: %s",prg_nm_get(),fnc_nm,var_2[*var_nbr_1]->nm);
-    for(idx_2=*var_nbr_1+1;idx_2<*var_nbr_2;idx_2++){
-      (void)fprintf(stderr,", %s",var_2[idx_2]->nm);
-    } /* end loop over idx_2 */
+    (void)fprintf(stderr,"%s: WARNING %s detects that file two has more variables than file one. The following variables, present only in file two, will not be present in the output file: ",prg_nm_get(),fnc_nm);
+       
+    for(idx_2=0;idx_2<*var_nbr_2;idx_2++){ 
+      for(idx_1=0;idx_1<*var_nbr_1;idx_1++)
+        if(!strcmp(var_out[idx_1]->nm,var_2[idx_2]->nm)) break;
+      if(idx_1==*var_nbr_1) 
+        /* print out var name of var in list 2 but not var_out */  
+        (void)fprintf(stderr,"%s, ",var_2[idx_2]->nm);
+    }  /* end loop over idx_2 */ 
+
     (void)fprintf(stderr,"\n");
     *var_nbr_2=*var_nbr_1;
   } /* end if asymmetric */
