@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_utl.c,v 1.143 2009/05/29 20:36:32 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_utl.c,v 1.150 2010/03/22 15:21:47 hmb Exp $ */
 
 /* Purpose: Variable utilities */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -12,7 +12,7 @@ int /* O [id] Output file variable ID */
 nco_cpy_var_dfn /* [fnc] Copy variable metadata from input to output file */
 (const int in_id, /* I [id] netCDF input file ID */
  const int out_id, /* I [id] netCDF output file ID */
- const int rec_dmn_id, /* I [id] Input file record dimension ID  */
+ const char *rec_dmn_nm, /* I [sng] Output file record dimension name  */
  const char * const var_nm, /* I [sng] Input variable name */
  const int dfl_lvl) /* I [enm] Deflate level [0..9] */
 {
@@ -25,11 +25,13 @@ nco_cpy_var_dfn /* [fnc] Copy variable metadata from input to output file */
 
   int *dmn_in_id;
   int *dmn_out_id;
+  int fl_fmt; /* [enm] Output file format */
   int idx;
   int nbr_dim;
   int rcd=NC_NOERR; /* [rcd] Return code */
   int var_in_id;
   int var_out_id;
+  int rec_dmn_out_id=NCO_REC_DMN_UNDEFINED;
   
   nc_type var_type;
   
@@ -42,6 +44,9 @@ nco_cpy_var_dfn /* [fnc] Copy variable metadata from input to output file */
   
   /* Get type of variable and number of dimensions */
   (void)nco_inq_var(in_id,var_in_id,(char *)NULL,&var_type,&nbr_dim,(int *)NULL,(int *)NULL);
+
+  /* Get unlimited dimension in output */
+  (void)nco_inq(out_id,(int*)NULL,(int*)NULL,(int*)NULL,&rec_dmn_out_id);
   
   /* Recall:
      1. Dimensions must be defined before variables
@@ -67,44 +72,56 @@ nco_cpy_var_dfn /* [fnc] Copy variable metadata from input to output file */
     
     /* Define dimension in output file if necessary */
     if(rcd_lcl != NC_NOERR){
-      if(dmn_in_id[idx] != rec_dmn_id){
+      if(!rec_dmn_nm || strcmp(dmn_nm,rec_dmn_nm))
 	(void)nco_def_dim(out_id,dmn_nm,dmn_sz,dmn_out_id+idx);
-      }else{
+      else{
 	(void)nco_def_dim(out_id,dmn_nm,NC_UNLIMITED,dmn_out_id+idx);
-      } /* end else */
+        rec_dmn_out_id=dmn_out_id[idx];
+      } /* end else */ 
+
     } /* end if */
 
+    /* Very Important -blow out if record dim isn't the first record */
+    if( idx >0 && dmn_out_id[idx]==rec_dmn_out_id ){
+      (void)fprintf(stdout,"%s: ERROR You have defined the record dimension in output to be \"%s\". Yet in the variable \"%s\" the record dimension is dimension number %d  and not the 1st dimension. Consider using ncpdq to permute the record dimension.\n",prg_nm_get(),rec_dmn_nm,var_nm,idx+1);  
+        nco_exit(EXIT_FAILURE);
+    }  
+
   } /* end loop over dim */
   
   /* Define variable in output file */
   (void)nco_def_var(out_id,var_nm,var_type,nbr_dim,dmn_out_id,&var_out_id);
 
-  /* Deflation */
-  if(nbr_dim > 0){
-    int shuffle; /* [flg] Turn on shuffle filter */
-    int deflate; /* [flg] Turn on deflate filter */
-    int dfl_lvl_in; /* [enm] Deflate level [0..9] */
-    rcd=nco_inq_var_deflate(in_id,var_in_id,&shuffle,&deflate,&dfl_lvl_in);
-    /* Copy original deflation settings */
-    if(deflate || shuffle) (void)nco_def_var_deflate(out_id,var_out_id,deflate,shuffle,dfl_lvl_in);
-    /* Overwrite HDF Lempel-Ziv compression level, if requested */
-    if(dfl_lvl > 0) (void)nco_def_var_deflate(out_id,var_out_id,(int)True,(int)True,dfl_lvl);
-  } /* endif */
-
-  /* Chunking */
-  if(nbr_dim > 0){
-    int srg_typ; /* [enm] Storage type */
-    size_t *cnk_sz; /* [nbr] Chunksize list */
-    cnk_sz=(size_t *)nco_malloc(nbr_dim*sizeof(size_t));
-    rcd=nco_inq_var_chunking(in_id,var_in_id,&srg_typ,cnk_sz);
-    /* Copy original chunking settings */
-    if(srg_typ == NC_CHUNKED){
-      if(dbg_lvl_get() >= nco_dbg_var ) (void)fprintf(stdout,"%s: DEBUG %s copying input-to-ouput chunking information for %s\n",prg_nm_get(),fnc_nm,var_nm);
-      (void)nco_def_var_chunking(out_id,var_out_id,srg_typ,cnk_sz);
+  /* Duplicate netCDF4 settings when possible */
+  rcd=nco_inq_format(out_id,&fl_fmt);
+  if(fl_fmt == NC_FORMAT_NETCDF4){
+    /* Deflation */
+    if(nbr_dim > 0){
+      int shuffle; /* [flg] Turn on shuffle filter */
+      int deflate; /* [flg] Turn on deflate filter */
+      int dfl_lvl_in; /* [enm] Deflate level [0..9] */
+      rcd=nco_inq_var_deflate(in_id,var_in_id,&shuffle,&deflate,&dfl_lvl_in);
+      /* Copy original deflation settings */
+      if(deflate || shuffle) (void)nco_def_var_deflate(out_id,var_out_id,deflate,shuffle,dfl_lvl_in);
+      /* Overwrite HDF Lempel-Ziv compression level, if requested */
+      if(dfl_lvl > 0) (void)nco_def_var_deflate(out_id,var_out_id,(int)True,(int)True,dfl_lvl);
     } /* endif */
-    cnk_sz=(size_t *)nco_free(cnk_sz);
-  } /* endif */
-
+    
+    /* Chunking */
+    if(nbr_dim > 0){
+      int srg_typ; /* [enm] Storage type */
+      size_t *cnk_sz; /* [nbr] Chunksize list */
+      cnk_sz=(size_t *)nco_malloc(nbr_dim*sizeof(size_t));
+      rcd=nco_inq_var_chunking(in_id,var_in_id,&srg_typ,cnk_sz);
+      /* Copy original chunking settings */
+      if(srg_typ == NC_CHUNKED){
+	if(dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stdout,"%s: DEBUG %s copying input-to-ouput chunking information for %s\n",prg_nm_get(),fnc_nm,var_nm);
+	(void)nco_def_var_chunking(out_id,var_out_id,srg_typ,cnk_sz);
+      } /* endif */
+      cnk_sz=(size_t *)nco_free(cnk_sz);
+    } /* endif */
+  } /* !NC_FORMAT_NETCDF4 */ 
+  
   /* Free space holding dimension IDs */
   dmn_in_id=(int *)nco_free(dmn_in_id);
   dmn_out_id=(int *)nco_free(dmn_out_id);
@@ -116,7 +133,7 @@ int /* O [id] Output file variable ID */
 nco_cpy_var_dfn_lmt /* Copy variable metadata from input to output file */
 (const int in_id, /* I [id] netCDF input file ID */
  const int out_id, /* I [id] netCDF output file ID */
- const int rec_dmn_id, /* I [id] Input file record dimension ID  */
+ const char *rec_dmn_nm, /* I [sng] Output file record dimension name  */
  const char * const var_nm, /* I [sng] Input variable name */
  CST_X_PTR_CST_PTR_CST_Y(lmt_all_sct,lmt_all_lst), /* I [sct] Hyperslab limits */
  const int lmt_all_lst_nbr, /* I [nbr] Number of hyperslab limits */
@@ -128,11 +145,13 @@ nco_cpy_var_dfn_lmt /* Copy variable metadata from input to output file */
 
   int *dmn_in_id;
   int *dmn_out_id;
+  int fl_fmt; /* [enm] Output file format */
   int idx;
   int nbr_dim;
   int rcd=NC_NOERR; /* [rcd] Return code */
   int var_in_id;
   int var_out_id;
+  int rec_dmn_out_id=NCO_REC_DMN_UNDEFINED;
   
   nc_type var_type;
 
@@ -145,6 +164,11 @@ nco_cpy_var_dfn_lmt /* Copy variable metadata from input to output file */
   
   /* Get type of variable and number of dimensions */
   (void)nco_inq_var(in_id,var_in_id,(char *)NULL,&var_type,&nbr_dim,(int *)NULL,(int *)NULL);
+
+
+  /* Get unlimited dimension in output */
+  (void)nco_inq(out_id,(int*)NULL,(int*)NULL,(int*)NULL,&rec_dmn_out_id);
+
   
   /* Recall:
      1. Dimensions must be defined before variable
@@ -170,7 +194,7 @@ nco_cpy_var_dfn_lmt /* Copy variable metadata from input to output file */
     
     /* If dimension has not been defined, copy it */
     if(rcd_lcl != NC_NOERR){
-      if(dmn_in_id[idx] != rec_dmn_id){
+      if(!rec_dmn_nm || strcmp(dmn_nm,rec_dmn_nm) ){
 	int lmt_all_idx;
 
 	/* Does dimension have any user-specified limits? */
@@ -183,36 +207,49 @@ nco_cpy_var_dfn_lmt /* Copy variable metadata from input to output file */
 	(void)nco_def_dim(out_id,dmn_nm,dmn_sz,dmn_out_id+idx);
       }else{
 	(void)nco_def_dim(out_id,dmn_nm,NC_UNLIMITED,dmn_out_id+idx);
+        rec_dmn_out_id=dmn_out_id[idx];
       } /* end else */
     } /* end if */
+
+    /* Very Important -blow out if record dim isn't the first record */
+    if( idx >0 && dmn_out_id[idx]==rec_dmn_out_id ){
+      (void)fprintf(stdout,"%s: ERROR You have defined the record dimension in output to be \"%s\". Yet in the variable \"%s\" the record dimension is dimension number %d  and not the 1st dimension. Consider using ncpdq to permute the record dimension.\n",prg_nm_get(),rec_dmn_nm,var_nm,idx+1);  
+      nco_exit(EXIT_FAILURE);
+    } /* end if */
+
   } /* end loop over dim */
   
   /* Define variable in output file */
   (void)nco_def_var(out_id,var_nm,var_type,nbr_dim,dmn_out_id,&var_out_id);
   
-  /* Deflation */
-  if(nbr_dim > 0){
-    int shuffle; /* [flg] Turn on shuffle filter */
-    int deflate; /* [flg] Turn on deflate filter */
-    int dfl_lvl_in; /* [enm] Deflate level [0..9] */
-    rcd=nco_inq_var_deflate(in_id,var_in_id,&shuffle,&deflate,&dfl_lvl_in);
-    /* Copy original deflation settings */
-    if(deflate || shuffle) (void)nco_def_var_deflate(out_id,var_out_id,deflate,shuffle,dfl_lvl_in);
-    /* Overwrite HDF Lempel-Ziv compression level, if requested */
-    if(dfl_lvl > 0) (void)nco_def_var_deflate(out_id,var_out_id,(int)True,(int)True,dfl_lvl);
-  } /* endif */
-
-  /* Chunking */
-  if(nbr_dim > 0){
-    int srg_typ; /* [enm] Storage type */
-    size_t *cnk_sz; /* [nbr] Chunksize list */
-    cnk_sz=(size_t *)nco_malloc(nbr_dim*sizeof(size_t));
-    rcd=nco_inq_var_chunking(in_id,var_in_id,&srg_typ,cnk_sz);
-    /* Copy original chunking settings */
-    if(srg_typ == NC_CHUNKED) (void)nco_def_var_chunking(out_id,var_out_id,srg_typ,cnk_sz);
-    cnk_sz=(size_t *)nco_free(cnk_sz);
-  } /* endif */
-
+  /* Duplicate netCDF4 settings when possible */
+  rcd=nco_inq_format(out_id,&fl_fmt);
+  if(fl_fmt == NC_FORMAT_NETCDF4){
+    
+    /* Deflation */
+    if(nbr_dim > 0){
+      int shuffle; /* [flg] Turn on shuffle filter */
+      int deflate; /* [flg] Turn on deflate filter */
+      int dfl_lvl_in; /* [enm] Deflate level [0..9] */
+      rcd=nco_inq_var_deflate(in_id,var_in_id,&shuffle,&deflate,&dfl_lvl_in);
+      /* Copy original deflation settings */
+      if(deflate || shuffle) (void)nco_def_var_deflate(out_id,var_out_id,deflate,shuffle,dfl_lvl_in);
+      /* Overwrite HDF Lempel-Ziv compression level, if requested */
+      if(dfl_lvl > 0) (void)nco_def_var_deflate(out_id,var_out_id,(int)True,(int)True,dfl_lvl);
+    } /* endif */
+    
+    /* Chunking */
+    if(nbr_dim > 0){
+      int srg_typ; /* [enm] Storage type */
+      size_t *cnk_sz; /* [nbr] Chunksize list */
+      cnk_sz=(size_t *)nco_malloc(nbr_dim*sizeof(size_t));
+      rcd=nco_inq_var_chunking(in_id,var_in_id,&srg_typ,cnk_sz);
+      /* Copy original chunking settings */
+      if(srg_typ == NC_CHUNKED) (void)nco_def_var_chunking(out_id,var_out_id,srg_typ,cnk_sz);
+      cnk_sz=(size_t *)nco_free(cnk_sz);
+    } /* endif */
+  } /* !NC_FORMAT_NETCDF4 */ 
+  
   /* Free space holding dimension IDs */
   dmn_in_id=(int *)nco_free(dmn_in_id);
   dmn_out_id=(int *)nco_free(dmn_out_id);
@@ -601,10 +638,10 @@ nco_var_dpl /* [fnc] Duplicate input variable */
   (void)memcpy((void *)var_cpy,(const void *)var,sizeof(var_sct));
 
   /* Make sure var_free() frees names when variable is destructed */
-  if(var->nm != NULL) var_cpy->nm=(char *)strdup(var->nm);
+  if(var->nm) var_cpy->nm=(char *)strdup(var->nm);
 
   /* Deep-copy dyamically allocated arrays from original to copy */
-  if(var->val.vp != NULL){
+  if(var->val.vp){
     var_cpy->val.vp=(void *)nco_malloc_dbg(var_cpy->sz*nco_typ_lng(var_cpy->type),"Unable to malloc() value buffer in variable deep-copy",fnc_nm);
     (void)memcpy((void *)(var_cpy->val.vp),(void *)(var->val.vp),var_cpy->sz*nco_typ_lng(var_cpy->type));
     /* Deep-copy string data, if any */
@@ -626,47 +663,47 @@ nco_var_dpl /* [fnc] Duplicate input variable */
 	 Therefore not necessary to un-typecast pointer unions */
     } /* endif type */
   } /* end if val */
-  if(var->mss_val.vp != NULL){
+  if(var->mss_val.vp){
     var_cpy->mss_val.vp=(void *)nco_malloc(nco_typ_lng(var_cpy->type));
     (void)memcpy((void *)(var_cpy->mss_val.vp),(void *)(var->mss_val.vp),nco_typ_lng(var_cpy->type));
   } /* end if */
-  if(var->tally != NULL){
+  if(var->tally){
     var_cpy->tally=(long *)nco_malloc_dbg(var_cpy->sz*sizeof(long),"Unable to malloc() tally buffer in variable deep-copy",fnc_nm);
     (void)memcpy((void *)(var_cpy->tally),(void *)(var->tally),var_cpy->sz*sizeof(long));
   } /* end if */
-  if(var->dim != NULL){
+  if(var->dim){
     var_cpy->dim=(dmn_sct **)nco_malloc(var_cpy->nbr_dim*sizeof(dmn_sct *));
     (void)memcpy((void *)(var_cpy->dim),(void *)(var->dim),var_cpy->nbr_dim*sizeof(var->dim[0]));
   } /* end if */
-  if(var->dmn_id != NULL){
+  if(var->dmn_id){
     var_cpy->dmn_id=(int *)nco_malloc(var_cpy->nbr_dim*sizeof(int));
     (void)memcpy((void *)(var_cpy->dmn_id),(void *)(var->dmn_id),var_cpy->nbr_dim*sizeof(var->dmn_id[0]));
   } /* end if */
-  if(var->cnk_sz != NULL){
+  if(var->cnk_sz){
     var_cpy->cnk_sz=(size_t *)nco_malloc(var_cpy->nbr_dim*sizeof(size_t));
     (void)memcpy((void *)(var_cpy->cnk_sz),(void *)(var->cnk_sz),var_cpy->nbr_dim*sizeof(var->cnk_sz[0]));
   } /* end if */
-  if(var->cnt != NULL){
+  if(var->cnt){
     var_cpy->cnt=(long *)nco_malloc(var_cpy->nbr_dim*sizeof(long));
     (void)memcpy((void *)(var_cpy->cnt),(void *)(var->cnt),var_cpy->nbr_dim*sizeof(var->cnt[0]));
   } /* end if */
-  if(var->srt != NULL){
+  if(var->srt){
     var_cpy->srt=(long *)nco_malloc(var_cpy->nbr_dim*sizeof(long));
     (void)memcpy((void *)(var_cpy->srt),(void *)(var->srt),var_cpy->nbr_dim*sizeof(var->srt[0]));
   } /* end if */
-  if(var->end != NULL){
+  if(var->end){
     var_cpy->end=(long *)nco_malloc(var_cpy->nbr_dim*sizeof(long));
     (void)memcpy((void *)(var_cpy->end),(void *)(var->end),var_cpy->nbr_dim*sizeof(var->end[0]));
   } /* end if */
-  if(var->srd != NULL){
+  if(var->srd){
     var_cpy->srd=(long *)nco_malloc(var_cpy->nbr_dim*sizeof(long));
     (void)memcpy((void *)(var_cpy->srd),(void *)(var->srd),var_cpy->nbr_dim*sizeof(var->srd[0]));
   } /* end if */
-  if(var->scl_fct.vp != NULL){
+  if(var->scl_fct.vp){
     var_cpy->scl_fct.vp=(void *)nco_malloc(nco_typ_lng(var_cpy->typ_upk));
     (void)memcpy((void *)(var_cpy->scl_fct.vp),(void *)(var->scl_fct.vp),nco_typ_lng(var_cpy->typ_upk));
   } /* end if */
-  if(var->add_fst.vp != NULL){
+  if(var->add_fst.vp){
     var_cpy->add_fst.vp=(void *)nco_malloc(nco_typ_lng(var_cpy->typ_upk));
     (void)memcpy((void *)(var_cpy->add_fst.vp),(void *)(var->add_fst.vp),nco_typ_lng(var_cpy->typ_upk));
   } /* end if */
@@ -967,7 +1004,7 @@ nco_var_dfn /* [fnc] Define variables and write their attributes to output file
     if(rcd != NC_NOERR){
       
       /* TODO #116: There is a problem here in that var_out[idx]->nbr_dim is never explicitly set to the actual number of output dimensions, rather, it is simply copied from var[idx]. When var_out[idx] actually has 0 dimensions, the loop executes once anyway, and an erroneous index into the dmn_out[idx] array is attempted. Fix is to explicitly define var_out[idx]->nbr_dim. Until this is done, anything in ncwa that explicitly depends on var_out[idx]->nbr_dim is suspect. The real problem is that, in ncwa, nco_var_avg() expects var_out[idx]->nbr_dim to contain the input, rather than output, number of dimensions. The routine, nco_var_dfn() was designed to call the simple branch when dmn_ncl == 0, i.e., for operators besides ncwa. However, when ncwa averages all dimensions in output file, nbr_dmn_ncl == 0 so the wrong branch would get called unless we specifically use this branch whenever ncwa is calling. */
-      if(dmn_ncl != NULL || prg_id == ncwa){
+      if(dmn_ncl || prg_id == ncwa){
 	/* ...operator is ncwa and/or changes variable rank... */
 	int idx_ncl;
 	/* Initialize number of dimensions for current variable */
@@ -1324,3 +1361,34 @@ nco_var_srd_srt_set /* [fnc] Assign zero-start and unity-stride vectors to varia
   } /* end loop over variables */
   
 } /* end nco_var_srd_srt_set() */
+
+
+  
+void
+nco_var_dmn_refresh /* [fnc] Refresh var hyperslab info with var->dim[] info */
+(var_sct ** const var, /* I [sct] Variables to refresh */
+ const int nbr_var) /* I [nbr] Number of structures in variable structure list */
+{
+  int idx;
+  int jdx;
+  for(idx=0;idx<nbr_var;idx++){
+    long sz;
+    long sz_rec;
+    sz=1;
+    sz_rec=1;
+    var_sct *var_tmp;
+    var_tmp=var[idx];
+    
+    for(jdx=0 ; jdx<var_tmp->nbr_dim ; jdx++){
+      var_tmp->srt[jdx]=var_tmp->dim[jdx]->srt; 
+      var_tmp->end[jdx]=var_tmp->dim[jdx]->end;
+      var_tmp->cnt[jdx]=var_tmp->dim[jdx]->cnt;
+      var_tmp->srd[jdx]=var_tmp->dim[jdx]->srd;
+      sz*=var_tmp->dim[jdx]->cnt;
+      if(jdx >0) sz_rec*=var_tmp->dim[jdx]->cnt;
+    }
+     var_tmp->sz=sz; 
+     var_tmp->sz_rec=sz_rec;
+  } 
+
+}  /* end nco_var_dmn_refresh() */
