@@ -1,11 +1,11 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncwa.c,v 1.268 2009/05/29 20:12:36 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncwa.c,v 1.273 2010/01/27 09:36:31 zender Exp $ */
 
 /* ncwa -- netCDF weighted averager */
 
 /* Purpose: Compute averages of specified hyperslabs of specfied variables
    in a single input netCDF file and output them to a single file. */
 
-/* Copyright (C) 1995--2009 Charlie Zender
+/* Copyright (C) 1995--2010 Charlie Zender
 
    License: GNU General Public License (GPL) Version 3
    The full license text is at http://www.gnu.org/copyleft/gpl.html 
@@ -118,12 +118,13 @@ main(int argc,char **argv)
   char *optarg_lcl=NULL; /* [sng] Local copy of system optarg */
   char *wgt_nm=NULL;
   
-  const char * const CVS_Id="$Id: ncwa.c,v 1.268 2009/05/29 20:12:36 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.268 $";
-  const char * const opt_sht_lst="34Aa:B:bCcD:d:FhIL:l:M:m:nNOo:p:rRT:t:v:Ww:xy:-:";
+  const char * const CVS_Id="$Id: ncwa.c,v 1.273 2010/01/27 09:36:31 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.273 $";
+  const char * const opt_sht_lst="346Aa:B:bCcD:d:FhIL:l:M:m:nNOo:p:rRT:t:v:Ww:xy:-:";
   
 #if defined(__cplusplus) || defined(PGI_CC)
   ddra_info_sct ddra_info;
+  ddra_info.flg_ddra=False;
 #else /* !__cplusplus */
   ddra_info_sct ddra_info={.MRV_flg=False,.flg_ddra=False,.lmn_nbr=0LL,.lmn_nbr_avg=0LL,.lmn_nbr_wgt=0LL,.nco_op_typ=nco_op_nil,.rnk_avg=0,.rnk_var=0,.rnk_wgt=0,.tmr_flg=nco_tmr_srt,.var_idx=0,.wgt_brd_flg=False,.wrd_sz=0};
 #endif /* !__cplusplus */
@@ -320,6 +321,9 @@ main(int argc,char **argv)
     case '4': /* Catch-all to prescribe output storage format */
       if(!strcmp(opt_crr,"64bit")) fl_out_fmt=NC_FORMAT_64BIT; else fl_out_fmt=NC_FORMAT_NETCDF4; 
       break;
+    case '6': /* Request netCDF3 64-bit offset output storage format */
+      fl_out_fmt=NC_FORMAT_64BIT;
+      break;
     case 'A': /* Toggle FORCE_APPEND */
       FORCE_APPEND=!FORCE_APPEND;
       break;
@@ -444,7 +448,7 @@ main(int argc,char **argv)
       nco_exit(EXIT_FAILURE);
       break;
     } /* end switch */
-    if(opt_crr != NULL) opt_crr=(char *)nco_free(opt_crr);
+    if(opt_crr) opt_crr=(char *)nco_free(opt_crr);
   } /* end while loop */
 
   /* Parse mask string */
@@ -655,7 +659,7 @@ main(int argc,char **argv)
   (void)nco_var_dfn(in_id,fl_out,out_id,var_out,nbr_xtr,dmn_out,nbr_dmn_out,nco_pck_plc_nil,nco_pck_map_nil,dfl_lvl);
 
   /* Add new missing values to output file while in define mode */
-  if(msk_nm != NULL){
+  if(msk_nm){
     for(idx=0;idx<nbr_var_prc;idx++){
       /* Define for var_prc_out because mss_val for var_prc will be overwritten in nco_var_mtd_refresh() */
       if(!var_prc_out[idx]->has_mss_val){
@@ -699,7 +703,7 @@ main(int argc,char **argv)
     if(False) (void)nco_fl_cmp_err_chk();
 
     /* Find weighting variable in input file */
-    if(wgt_nm != NULL){
+    if(wgt_nm){
       int wgt_id;
       
       rcd=nco_inq_varid(in_id,wgt_nm,&wgt_id);
@@ -716,7 +720,7 @@ main(int argc,char **argv)
     } /* end if */
 
     /* Find mask variable in input file */
-    if(msk_nm != NULL){
+    if(msk_nm){
       int msk_id;
       
       rcd=nco_inq_varid(in_id,msk_nm,&msk_id);
@@ -770,7 +774,7 @@ main(int argc,char **argv)
       var_prc[idx]=nco_typ_cnv_rth(var_prc[idx],nco_op_typ);
       var_prc_out[idx]=nco_typ_cnv_rth(var_prc_out[idx],nco_op_typ);
       
-      if(msk_nm != NULL && (!var_prc[idx]->is_crd_var || WGT_MSK_CRD_VAR)){
+      if(msk_nm && (!var_prc[idx]->is_crd_var || WGT_MSK_CRD_VAR)){
 	msk_out=nco_var_cnf_dmn(var_prc[idx],msk,msk_out,MUST_CONFORM,&DO_CONFORM_MSK);
 	/* If msk and var did not conform then do not mask var! */
 	if(DO_CONFORM_MSK){
@@ -798,7 +802,7 @@ main(int argc,char **argv)
 	  break;
 	} /* end case */
       } /* var_prc[idx]->is_crd_var */
-      if(wgt_nm != NULL && (!var_prc[idx]->is_crd_var || WGT_MSK_CRD_VAR)){
+      if(wgt_nm && (!var_prc[idx]->is_crd_var || WGT_MSK_CRD_VAR)){
 	/* fxm: nco_var_cnf_dmn() has bug where it does not allocate tally array
 	   for weights that do already conform to var_prc. TODO #114. */
 	wgt_out=nco_var_cnf_dmn(var_prc[idx],wgt,wgt_out,MUST_CONFORM,&DO_CONFORM_WGT);
@@ -836,7 +840,7 @@ main(int argc,char **argv)
 	  switch(wgt_avg->type){
 	  case NC_FLOAT: mss_val_dbl=wgt_avg->mss_val.fp[0]; break; 
 	  case NC_DOUBLE: mss_val_dbl=wgt_avg->mss_val.dp[0]; break; 
-	  case NC_INT: mss_val_dbl=wgt_avg->mss_val.lp[0]; break;
+	  case NC_INT: mss_val_dbl=wgt_avg->mss_val.ip[0]; break;
 	  case NC_SHORT: mss_val_dbl=wgt_avg->mss_val.sp[0]; break;
 	  case NC_USHORT: mss_val_dbl=wgt_avg->mss_val.usp[0]; break;
 	  case NC_UINT: mss_val_dbl=wgt_avg->mss_val.uip[0]; break;
@@ -855,7 +859,7 @@ main(int argc,char **argv)
 	/* Free current input buffer */
 	var_prc[idx]->val.vp=nco_free(var_prc[idx]->val.vp);
 
-	if(msk_nm != NULL && DO_CONFORM_MSK){
+	if(msk_nm && DO_CONFORM_MSK){
 	  /* Must mask weight in same fashion as variable was masked
 	     If msk and var did not conform then do not mask wgt
 	     Ensure wgt_avg has a missing value */
@@ -888,7 +892,7 @@ main(int argc,char **argv)
 	} /* endif */
 	/* Divide numerator by denominator */
 	/* Diagnose common PEBCAK before it causes core dump */
-	if(var_prc_out[idx]->sz == 1L && var_prc_out[idx]->type == NC_INT && var_prc_out[idx]->val.lp[0] == 0){
+	if(var_prc_out[idx]->sz == 1L && var_prc_out[idx]->type == NC_INT && var_prc_out[idx]->val.ip[0] == 0){
 	  (void)fprintf(fp_stdout,"%s: ERROR Weight in denominator weight = 0.0, will cause SIGFPE\n%s: HINT Sum of masked, averaged weights must be non-zero\n%s: HINT A possible workaround is to remove variable \"%s\" from output file using \"%s -x -v %s ...\"\n%s: Expecting core dump...now!\n",prg_nm,prg_nm,prg_nm,var_prc_out[idx]->nm,prg_nm,var_prc_out[idx]->nm,prg_nm);
 	} /* end if */
 	/* Rather complex conditional statement is shorter than switch() */
@@ -901,7 +905,7 @@ main(int argc,char **argv)
 	  (void)nco_var_dvd(var_prc_out[idx]->type,var_prc_out[idx]->sz,var_prc_out[idx]->has_mss_val,var_prc_out[idx]->mss_val,wgt_avg->val,var_prc_out[idx]->val);
 	} /* endif */
 	/* Free wgt_avg, but keep wgt_out, after each use */
-	if(wgt_avg != NULL) wgt_avg=nco_var_free(wgt_avg);
+	if(wgt_avg) wgt_avg=nco_var_free(wgt_avg);
 	/* End of branch for normalization when weights were specified */
       }else if(NRM_BY_DNM){
 	/* Branch for normalization when no weights were specified
@@ -981,10 +985,10 @@ main(int argc,char **argv)
 
 	/* Assign remaining input for DDRA diagnostics */
 	ddra_info.lmn_nbr=var_prc[idx]->sz; /* [nbr] Variable size */
-	if(wgt != NULL) ddra_info.lmn_nbr_wgt=wgt->sz; /* [nbr] Weight size */
+	if(wgt) ddra_info.lmn_nbr_wgt=wgt->sz; /* [nbr] Weight size */
 	ddra_info.nco_op_typ=nco_op_typ; /* [enm] Operation type */
 	ddra_info.rnk_var=var_prc[idx]->nbr_dim; /* I [nbr] Variable rank (in input file) */
-	if(wgt != NULL) ddra_info.rnk_wgt=wgt->nbr_dim; /* [nbr] Rank of weight */
+	if(wgt) ddra_info.rnk_wgt=wgt->nbr_dim; /* [nbr] Rank of weight */
 	ddra_info.var_idx=idx; /* [enm] Index */
 	ddra_info.wrd_sz=nco_typ_lng(var_prc[idx]->type); /* [B] Bytes per element */
 
@@ -1018,28 +1022,28 @@ main(int argc,char **argv)
   if(flg_cln){
     /* ncwa-specific memory */
     if(dmn_avg_nbr > 0) dmn_avg=(dmn_sct **)nco_free(dmn_avg);
-    if(msk != NULL) msk=nco_var_free(msk);
-    if(msk_nm != NULL) msk_nm=(char *)nco_free(msk_nm);
-    if(msk_out != NULL) msk_out=nco_var_free(msk_out);
-    if(msk_cnd_sng != NULL) msk_cnd_sng=(char *)nco_free(msk_cnd_sng);
-    if(wgt != NULL) wgt=nco_var_free(wgt);
-    if(wgt_avg != NULL) wgt_avg=nco_var_free(wgt_avg);
-    if(wgt_nm != NULL) wgt_nm=(char *)nco_free(wgt_nm);
-    if(wgt_out != NULL) wgt_out=nco_var_free(wgt_out);
+    if(msk) msk=nco_var_free(msk);
+    if(msk_nm) msk_nm=(char *)nco_free(msk_nm);
+    if(msk_out) msk_out=nco_var_free(msk_out);
+    if(msk_cnd_sng) msk_cnd_sng=(char *)nco_free(msk_cnd_sng);
+    if(wgt) wgt=nco_var_free(wgt);
+    if(wgt_avg) wgt_avg=nco_var_free(wgt_avg);
+    if(wgt_nm) wgt_nm=(char *)nco_free(wgt_nm);
+    if(wgt_out) wgt_out=nco_var_free(wgt_out);
     
     /* NCO-generic clean-up */
     /* Free individual strings/arrays */
-    if(cmd_ln != NULL) cmd_ln=(char *)nco_free(cmd_ln);
-    if(fl_in != NULL) fl_in=(char *)nco_free(fl_in);
-    if(fl_out != NULL) fl_out=(char *)nco_free(fl_out);
-    if(fl_out_tmp != NULL) fl_out_tmp=(char *)nco_free(fl_out_tmp);
-    if(fl_pth != NULL) fl_pth=(char *)nco_free(fl_pth);
-    if(fl_pth_lcl != NULL) fl_pth_lcl=(char *)nco_free(fl_pth_lcl);
-    if(in_id_arr != NULL) in_id_arr=(int *)nco_free(in_id_arr);
+    if(cmd_ln) cmd_ln=(char *)nco_free(cmd_ln);
+    if(fl_in) fl_in=(char *)nco_free(fl_in);
+    if(fl_out) fl_out=(char *)nco_free(fl_out);
+    if(fl_out_tmp) fl_out_tmp=(char *)nco_free(fl_out_tmp);
+    if(fl_pth) fl_pth=(char *)nco_free(fl_pth);
+    if(fl_pth_lcl) fl_pth_lcl=(char *)nco_free(fl_pth_lcl);
+    if(in_id_arr) in_id_arr=(int *)nco_free(in_id_arr);
     /* Free lists of strings */
-    if(fl_lst_in != NULL && fl_lst_abb == NULL) fl_lst_in=nco_sng_lst_free(fl_lst_in,fl_nbr); 
-    if(fl_lst_in != NULL && fl_lst_abb != NULL) fl_lst_in=nco_sng_lst_free(fl_lst_in,1);
-    if(fl_lst_abb != NULL) fl_lst_abb=nco_sng_lst_free(fl_lst_abb,abb_arg_nbr);
+    if(fl_lst_in && fl_lst_abb == NULL) fl_lst_in=nco_sng_lst_free(fl_lst_in,fl_nbr); 
+    if(fl_lst_in && fl_lst_abb) fl_lst_in=nco_sng_lst_free(fl_lst_in,1);
+    if(fl_lst_abb) fl_lst_abb=nco_sng_lst_free(fl_lst_abb,abb_arg_nbr);
     if(var_lst_in_nbr > 0) var_lst_in=nco_sng_lst_free(var_lst_in,var_lst_in_nbr);
     /* Free limits */
     for(idx=0;idx<lmt_nbr;idx++) lmt_arg[idx]=(char *)nco_free(lmt_arg[idx]);
